#! /bin/sh
# /raid2/cliu/sstdat/script/navy1718-finv2-oisst4-oper.sh

# run both bias and nobias OI in the same code
# set -x # turns on echo  for script
# set +x # turns off echo for script


# Chunying Liu  Aug 2008

cd /raid2/cliu/sstday/script
 
. /usr/local/lf9562/bash_setup   # setup the Fortran lib for cron job
GASCRP='/home/rreynold/grads_lib'
PATH=$PATH:/home/cliu/netcdf/netcdf-3.6.0-p1/f90/bin
export PATH GADDIR GASCRP
export NFf90=/home/cliu/netcdf/netcdf-3.6.0-p1/f90
ulimit -s unlimited
umask 002

CreateMNF() {
 local CMErr='none'
 if [ -s $1 ];then
   local MD5Ar=( $(md5sum --binary $1 |tr -s ' ' |tr -d '\*') )
   if [ ${#MD5Ar[@]} -eq 2 ];then
     local FSZ=$(find ${1%/*}"/" -name "${1##*/}" -printf "%s")
     if [ ${#FSZ} -gt 0 ];then
       echo ${1##*/},${MD5Ar[0]},$FSZ > $1".mnf"
     else
       CMErr="FileSizeError"
     fi
   else
     CMErr="ChkSumError"
   fi
 else
   CMErr="FileNOTFound"
 fi
 if [ $CMErr != 'none' ];then
   echo CreateMNF Failed: $CMErr
 fi
}

#FTN2=/raid2/cliu/sstday/ftn              # FORTRAN CODES
#echo $FTN2

echo 'NAVY EOT BIAS CORRECTION NOAA19 METOP FINV2 OI RUN '

#echo "Script run today to produce sobs for yesterday"

curryear=`date '+%Y'`
currmon=`date '+%m'`
today=`date '+%d'`
hour=`date '+%H'`
min=`date '+%M'`
echo $curryear,$currmon,$today,$hour,$min

TMtoday=$curryear$currmon$today
#echo $TMtoday

#TMtoday=19811015

# TMstop is the last anylysis day, it is 14 days ago of today
   
TMstop=`sh /raid/cliu/shell_lib/finddate.sh $TMtoday d-15`
#echo attempt to run $TMstop
imstop=`expr $TMstop | cut -c5-6`

#get parm for NetCDF
iyre=`expr $TMstop | cut -c1-4`
imoe=`expr $TMstop | cut -c5-6`
idae=`expr $TMstop | cut -c7-8`

# read in from last run's output file to find out the analysis date which has a successful run

TMlast=`cat /raid2/cliu/sstday/script/oi_finv2.txt`
echo 'the last successful run date:'$TMlast


if [ "$TMlast" -ge "$TMstop" ]
then
echo Today is $TMtoday. The input data only allow OI run utill $TMstop.
echo $TMstop already run successful.
exit
fi

# the start date of this run is 
TMmid=`sh /raid/cliu/shell_lib/finddate.sh $TMlast d+1`
#echo start run date: $TMmid

# as if it is a historic run

echo ' start date' $TMmid
echo ' end   date' $TMstop

#get parm for NetCDF
iyrs=`expr $TMmid | cut -c1-4`
imos=`expr $TMmid | cut -c5-6`
idas=`expr $TMmid | cut -c7-8`

echo 'parameters for NetCDF run:' $iyrs$imos$idas'_'$iyre$imoe$idae

iyrmid=`expr $TMmid | cut -c1-4`
immid=`expr $TMmid | cut -c5-6`
idmid=`expr $TMmid | cut -c7-8`

echo $iyrmid
echo $immid
echo $idmid

YEARs=`echo $TMmid | cut -c 1-4`

FTN=/raid2/cliu/sstday/ftn4              # FORTRAN CODES
work=/raid2/sstday/$YEARs/work/eotanal/navy1718-finv2/       # WORKING_DIRECTORY
DATA=/raid2/cliu/sstday/script                  # Script directory
#
FMODE=/raid2/sstday/stats/eot6.damp-zero.ev130.ano.dat   # EOT modes file (filled)
MASK2D=/raid2/sstday/clim/lstags.twodeg.dat      # EOT Land/SEA FILE
CLIM2D=/raid2/sstday/clim/clim.71.00.gdat        # EOT Climate FILE
VARMD=/raid2/sstday/stats/var-mode    # Variance of each modes
#
RESID=/raid2/sstday/stats/residual-stat-v2
CORXY=/raid2/sstday/stats/cor4sm-stat-v2
FGVAR=/raid2/sstday/stats/path-incr-var-stat-v2
RFAC=/raid2/sstday/stats/error-cor-stat-v2
MASK=/raid2/sstday/clim/quarter-mask-extend
CLIM=/raid2/sstday/clim/oiclm4.mon
#
#
# Initial data for ship
#globc=0.14				# global ship bias adjustment
#
#
# Initial data for EOT weights
minz=750       		# minimum number of smoothed zonal points
njj=10			# number of latitude points for zonal smoothing  
minob=1	        	# minimum number of obs used in zonal average
ioff=1			# number of longitude boxes smoothed for zonal sub
joff=1   		# number of latitude boxes smoothed for zonal sub
ndays=15                # number of days used
drej=5.			# data REJECT LIMIT for ABSOLUTE SST increment 
crit=0.25	        # critical data/total area ratio 
modes=130	        # number of modes used <131
nby=7			# number of ship obs = 1 buoy obs 
nsh=1			# number of buoy obs = 1 
nst=1			# number of sat obs = 1 
yrbuoy=15		# character count of buoy first number of year
yrship=15		# character count of ship first number of year
yrsat=15		# character count of sat first number of year
daybuoy=40		# character count of buoy first number of date
dayship=40		# character count of ship first number of date
daysat=44		# character count of sat first number of data
#
# Initial data for EOT corrections
modes=130	        # number of modes used <131
nuse=5                  # number of weights used (1, 3, or 5, default is 1) 
dfw1=0.0625             # factor to smooth the weights: range 0 to 1    
dfw2=0.25		# factor to smooth the weights: range 0 to 1
dfw3=0.375		# factor to smooth the weights: range 0 to 1
dfw4=0.25		# factor to smooth the weights: range 0 to 1
dfw5=0.0625		# factor to smooth the weights: range 0 to 1
#

rmax=400.	# maximum x or y distance (km) over which obs are used.
nmax=22		# maximum number of obs are used. Must be <201
ifil=1		# number of times 1-2-1 smoothing is done; <1 no smoothing 
rej=5.		# bias REJECT LIMIT for ABSOLUTE super obs increment
nbias=4		# number of files to read of EOT bias estimates
nsat=1		# number independent satellite bias data sets 
iwarn=20	# Percentage of satellite data: if lower warning message printed 
#               # day and night obs from the same satellite are not independent 
 
iyrmid0=0000

echo 'working directory '$work
[ -d $work ] || mkdir -p $work
cd $work

# clean up any old source or  executable files
touch dum.f
touch dum.x
rm *.f
rm *.x
#


TMg=`sh /home/cliu/shell_lib/finddate.sh $TMmid d-1` 
   

while [ "$TMmid" -le "$TMstop" ]
do

# Initial data for OI

title='Daily-OI-V2, Final, Data (Ship, Buoy, AVHRR: NOAA19, METOP, NCEP-ice)' 


echo 'Analysis date ' $TMmid

echo 'First guess EOT date ' $TMg

YEARg=`echo $TMg | cut -c 1-4`
YEARs=`echo $TMmid | cut -c 1-4`


if [ "$iyrmid" -ne "$iyrmid0" ]
then
work=/raid2/sstday/$YEARs/work/eotanal/navy1718-finv2/
echo 'working directory '$work
[ -d $work ] || mkdir -p $work
cd $work

# Set up and Compile ship bias correction Analysis Code
#cp $FTN/shipbias4-col.f shipbias4.f 
#
#     echo 'COMPILE shipbias4.f'
#     lf95  --chk -g --trace --info -o shipbias4.x shipbias4.f 
#     lf95  -o shipbias4.x shipbias4.f 
#     err=$?
#     [ $err -ne 0 ] && exit
#
# Set up and Compile eot weight bias correction Analysis Code
cat $FTN/eotbias-wt4-col.f $FTN/lib/date.f> eotbias-wt4.f
#
     echo 'COMPILE eotbias-wt4-col.f'
#     lf95  --chk -g --trace --info -o eotwt4.x eotbias-wt4.f 
     lf95  -o eotwt4.x eotbias-wt4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
#
# Set up and Compile eot bias correction Analysis Code
cp $FTN/eotbias-cor4-col.f eotbias-cor4.f
#
     echo 'COMPILE eotbias-cor4.f'
#     lf95  --chk -g --trace --info -o eotcor4.x eotbias-cor4.f 
     lf95  -o eotcor4.x eotbias-cor4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
# Set up and Compile daily OI Analysis Code
cat $FTN/oisst4-col.f $FTN/lib/sposl.f $FTN/lib/spoco.f $FTN/lib/date.f> oi.f
#cat $FTN/biasbld.f $FTN/weaver_f90.f > bias.f
#
     echo 'COMPILE oisst4-col.f'
     lf95  -o oi.x oi.f 
     err=$?
     [ $err -ne 0 ] && exit


fi

TM=$TMmid

  echo 'compute OI for date ' $TM
  YEAR=`echo $TM | cut -c 1-4`
#
  TMm1=`sh $DATA/finddate.sh $TM d-1`
  YEARm1=`echo $TMm1 | cut -c 1-4`
  echo 'date for data 1-day in past' $TMm1
  echo 'First guess OI date ' $TMm1
#
  TMp1=`sh $DATA/finddate.sh $TM d+1`
  YEARp1=`echo $TMp1 | cut -c 1-4`
  echo 'date for data 1-day in future' $TMp1
#
  TMp2=`sh $DATA/finddate.sh $TM d+2`
  YEARp2=`echo $TMp2 | cut -c 1-4`
  echo 'date for data 2-day in future' $TMp2
#
  TMp3=`sh $DATA/finddate.sh $TM d+3`
  YEARp3=`echo $TMp3 | cut -c 1-4`
  echo 'date for data 3-day in future' $TMp3
#

  echo 'compute EOT weights for date (3 days in future wrt OI) ' $TMp3
#
WTSDayNV17p3=/raid2/sstday/$YEARp3/eotwt-finv2/navy-err/dsat17/wtday17.$TMp3
WTSNteNV17p3=/raid2/sstday/$YEARp3/eotwt-finv2/navy-err/nsat17/wtnte17.$TMp3
WTSDayNV18p3=/raid2/sstday/$YEARp3/eotwt-finv2/navy-err/dsat18/wtday18.$TMp3
WTSNteNV18p3=/raid2/sstday/$YEARp3/eotwt-finv2/navy-err/nsat18/wtnte18.$TMp3
#
#  Earlier weights needed for bias correction step (TMp2, TMp1, TM & TMm1)
#
WTSDayNV17p2=/raid2/sstday/$YEARp2/eotwt-finv2/navy-err/dsat17/wtday17.$TMp2
WTSNteNV17p2=/raid2/sstday/$YEARp2/eotwt-finv2/navy-err/nsat17/wtnte17.$TMp2
WTSDayNV18p2=/raid2/sstday/$YEARp2/eotwt-finv2/navy-err/dsat18/wtday18.$TMp2
WTSNteNV18p2=/raid2/sstday/$YEARp2/eotwt-finv2/navy-err/nsat18/wtnte18.$TMp2
#
WTSDayNV17p1=/raid2/sstday/$YEARp1/eotwt-finv2/navy-err/dsat17/wtday17.$TMp1
WTSNteNV17p1=/raid2/sstday/$YEARp1/eotwt-finv2/navy-err/nsat17/wtnte17.$TMp1
WTSDayNV18p1=/raid2/sstday/$YEARp1/eotwt-finv2/navy-err/dsat18/wtday18.$TMp1
WTSNteNV18p1=/raid2/sstday/$YEARp1/eotwt-finv2/navy-err/nsat18/wtnte18.$TMp1
#
WTSDayNV17=/raid2/sstday/$YEAR/eotwt-finv2/navy-err/dsat17/wtday17.$TM
WTSNteNV17=/raid2/sstday/$YEAR/eotwt-finv2/navy-err/nsat17/wtnte17.$TM
WTSDayNV18=/raid2/sstday/$YEAR/eotwt-finv2/navy-err/dsat18/wtday18.$TM
WTSNteNV18=/raid2/sstday/$YEAR/eotwt-finv2/navy-err/nsat18/wtnte18.$TM
#
WTSDayNV17m1=/raid2/sstday/$YEARm1/eotwt-finv2/navy-err/dsat17/wtday17.$TMm1
WTSNteNV17m1=/raid2/sstday/$YEARm1/eotwt-finv2/navy-err/nsat17/wtnte17.$TMm1
WTSDayNV18m1=/raid2/sstday/$YEARm1/eotwt-finv2/navy-err/dsat18/wtday18.$TMm1
WTSNteNV18m1=/raid2/sstday/$YEARm1/eotwt-finv2/navy-err/nsat18/wtnte18.$TMm1
#
BUOY=/raid2/sstday/yyyy/sobs/coad/buoy/buoy.dddddddd
#    12345678901234567890123456789012345678901234567890
#             1         2         3         4
SHIP=/raid2/sstday/yyyy/cobs/coad/ship/ship.dddddddd
#    12345678901234567890123456789012345678901234567890
#             1         2         3         4
SATDayNV17=/raid2/sstday/yyyy/sobs/navy/dsat17/dsat17.dddddddd
SATNteNV17=/raid2/sstday/yyyy/sobs/navy/nsat17/nsat17.dddddddd
SATDayNV18=/raid2/sstday/yyyy/sobs/navy/dsat18/dsat18.dddddddd
SATNteNV18=/raid2/sstday/yyyy/sobs/navy/nsat18/nsat18.dddddddd
#         12345678901234567890123456789012345678901234567890
#                  1         2         3         4
#  echo: BUOY. SHIP amd SAT* data fields accessed -3 to 3 days wrt to TMp3
#
#  The 1st eotwt4 input record is 5 minz,njj,minob,ioff,joff
#  The 2nd eotwt4 input record is 5 parameters: nby,nsh,nst,ndays,nmodes
#  The 3rd record is 3 parameters: yrbuoy yrship yrsat
#  The 4th record is 3 parameters: daybuoy dayship daysat
#  The 5th record is 3 paramters: drej crit
#  The 6th input record is the date
#  All remaining records are input and output file names which must be in order
#  The 1st file name is the two-degree land/sea mask
#  The 2nd file name is the monthly climate (1-deg)
#  The 3rd file name is the input EOT modes (filled over land with 0)
#  The 4th file name is the analyzed weights (output) 
#  The 5th file name is the input buoy data 
#  The 6th file name is the input ship data 
#  The 7th file name is the input satellite data
#  Multitple dates are read in and the complete file names
#    for these last 3 files are computed in the fortran code
#
#  Note all satellite fields, weights differ for day and night
#
echo " "
echo "minz njj minob ioff joff"
echo "nby nsh nst ndays modes"
echo "yrbuoy yrship yrsat"
echo "daybuoy dayship daysat"
echo "drej crit"
echo "TMp3"
echo " "
cat <<inxEOF> eotwt4-dayNV17
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit
$TMp3
$MASK2D
$CLIM2D
$FMODE
$WTSDayNV17p3
$BUOY
$SHIP
$SATDayNV17
inxEOF
cat eotwt4-dayNV17
#
cat <<inxEOF> eotwt4-nteNV17
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit
$TMp3
$MASK2D
$CLIM2D
$FMODE
$WTSNteNV17p3
$BUOY
$SHIP
$SATNteNV17
inxEOF
cat eotwt4-nteNV17   
#
cat <<inxEOF> eotwt4-dayNV18
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit 
$TMp3
$MASK2D
$CLIM2D
$FMODE
$WTSDayNV18p3
$BUOY
$SHIP
$SATDayNV18
inxEOF
cat eotwt4-dayNV18
#
cat <<inxEOF> eotwt4-nteNV18
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit 
$TMp3
$MASK2D
$CLIM2D
$FMODE
$WTSNteNV18p3
$BUOY
$SHIP
$SATNteNV18
inxEOF
cat eotwt4-nteNV18   
#
$work/eotwt4.x  -Wl,-T <eotwt4-dayNV17 
stopcode=$?  
echo 'eotwt4-dayNV17: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY17-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY17-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY17-day data error'
  exit
fi 


$work/eotwt4.x  -Wl,-T <eotwt4-nteNV17 
stopcode=$?  
echo 'eotwt4-nteNV17: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY17-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY17-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY17-nte data error'
  exit
fi 


$work/eotwt4.x  -Wl,-T <eotwt4-dayNV18 
stopcode=$?  
echo 'eotwt4-dayNV18: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY18-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY18-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY18-day data error'
  exit
fi 



$work/eotwt4.x  -Wl,-T <eotwt4-nteNV18 
stopcode=$?  
echo 'eotwt4-nteNV18: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY18-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY18-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY18-nte data error'
  exit
fi 



# end EOT Weight CORRECTION DONE
#
echo EOT Weight CORRECTION DONE
#
# begin EOT bias correction day & night
#
  echo 'compute EOT weights for date (1 day in future wrt OI) ' $TMp1
#
ANALDayNV17p1=/raid2/sstday/$YEARp1/eotcor-finv2/navy-err/dsat17/dsat17.$TMp1         
ANALNteNV17p1=/raid2/sstday/$YEARp1/eotcor-finv2/navy-err/nsat17/nsat17.$TMp1         
ANALDayNV18p1=/raid2/sstday/$YEARp1/eotcor-finv2/navy-err/dsat18/dsat18.$TMp1         
ANALNteNV18p1=/raid2/sstday/$YEARp1/eotcor-finv2/navy-err/nsat18/nsat18.$TMp1         
SATCORDayNV17p1=/raid2/sstday/$YEARp1/cobs/eotcor-finv2/navy-err/dsat17/dsat17.$TMp1
SATCORNteNV17p1=/raid2/sstday/$YEARp1/cobs/eotcor-finv2/navy-err/nsat17/nsat17.$TMp1
SATCORDayNV18p1=/raid2/sstday/$YEARp1/cobs/eotcor-finv2/navy-err/dsat18/dsat18.$TMp1
SATCORNteNV18p1=/raid2/sstday/$YEARp1/cobs/eotcor-finv2/navy-err/nsat18/nsat18.$TMp1
SATinDayNV17p1=/raid2/sstday/$YEARp1/sobs/navy/dsat17/dsat17.$TMp1
SATinNteNV17p1=/raid2/sstday/$YEARp1/sobs/navy/nsat17/nsat17.$TMp1
SATinDayNV18p1=/raid2/sstday/$YEARp1/sobs/navy/dsat18/dsat18.$TMp1
SATinNteNV18p1=/raid2/sstday/$YEARp1/sobs/navy/nsat18/nsat18.$TMp1
#
#  Earlier corrections needed for OI (TM & TMm1)
#
ANALDayNV17m1=/raid2/sstday/$YEARm1/eotcor-finv2/navy-err/dsat17/dsat17.$TMm1         
ANALNteNV17m1=/raid2/sstday/$YEARm1/eotcor-finv2/navy-err/nsat17/nsat17.$TMm1         
ANALDayNV18m1=/raid2/sstday/$YEARm1/eotcor-finv2/navy-err/dsat18/dsat18.$TMm1         
ANALNteNV18m1=/raid2/sstday/$YEARm1/eotcor-finv2/navy-err/nsat18/nsat18.$TMm1         
SATCORDayNV17m1=/raid2/sstday/$YEARm1/cobs/eotcor-finv2/navy-err/dsat17/dsat17.$TMm1
SATCORNteNV17m1=/raid2/sstday/$YEARm1/cobs/eotcor-finv2/navy-err/nsat17/nsat17.$TMm1
SATCORDayNV18m1=/raid2/sstday/$YEARm1/cobs/eotcor-finv2/navy-err/dsat18/dsat18.$TMm1
SATCORNteNV18m1=/raid2/sstday/$YEARm1/cobs/eotcor-finv2/navy-err/nsat18/nsat18.$TMm1
#
ANALDayNV17=/raid2/sstday/$YEAR/eotcor-finv2/navy-err/dsat17/dsat17.$TM         
ANALNteNV17=/raid2/sstday/$YEAR/eotcor-finv2/navy-err/nsat17/nsat17.$TM         
ANALDayNV18=/raid2/sstday/$YEAR/eotcor-finv2/navy-err/dsat18/dsat18.$TM         
ANALNteNV18=/raid2/sstday/$YEAR/eotcor-finv2/navy-err/nsat18/nsat18.$TM         
SATCORDayNV17=/raid2/sstday/$YEAR/cobs/eotcor-finv2/navy-err/dsat17/dsat17.$TM
SATCORNteNV17=/raid2/sstday/$YEAR/cobs/eotcor-finv2/navy-err/nsat17/nsat17.$TM
SATCORDayNV18=/raid2/sstday/$YEAR/cobs/eotcor-finv2/navy-err/dsat18/dsat18.$TM
SATCORNteNV18=/raid2/sstday/$YEAR/cobs/eotcor-finv2/navy-err/nsat18/nsat18.$TM
#
#  The 1st eotbias-cor4 input record has 2 parameters: nmodes, nuse
#  The 2nd eotbias-cor4 input record depends on nuse and has 1-9 parameters: dwf1,dwf2,...
#  The next input record is the date: computed by script 8 digits
#  All remaining records are input and output file names which must be in order
#  The 1st file name is the two-degree land/sea mask
#  The 2nd file name is the input EOT modes (filled over land with 0)
#  The 3rd file name is the variance of each of the 130 modes
#  Nuse (1-9) now determines the number of files read. They will be weighted by dwf
#        The weighting smoothing factors are applied in order: dwf1, ...
#  The next file name is the input uncorrected satellite data
#  The next file name is the output bias error estimate
#  The final file name is the output bias corrected satellite data 
#
#  Note all satellite fields, weights and biases differ for day and night
#
echo " "
echo "modes nuse"
echo "dfw values"
echo "TM"
echo " "
cat <<inxEOF> eotcor4-dayNV17
$modes $nuse
$dfw1 $dfw2 $dfw3 $dfw4 $dfw5
$TMp1
$MASK2D
$FMODE
$VARMD
$SATinDayNV17p1
$WTSDayNV17p3
$WTSDayNV17p2
$WTSDayNV17p1
$WTSDayNV17
$WTSDayNV17m1
$ANALDayNV17p1
$SATCORDayNV17p1
inxEOF
cat eotcor4-dayNV17
#
cat <<inxEOF> eotcor4-nteNV17
$modes $nuse
$dfw1 $dfw2 $dfw3 $dfw4 $dfw5
$TMp1
$MASK2D
$FMODE
$VARMD
$SATinNteNV17p1
$WTSNteNV17p3
$WTSNteNV17p2
$WTSNteNV17p1
$WTSNteNV17
$WTSNteNV17m1
$ANALNteNV17p1
$SATCORNteNV17p1
inxEOF
cat eotcor4-nteNV17   
#
cat <<inxEOF> eotcor4-dayNV18
$modes $nuse
$dfw1 $dfw2 $dfw3 $dfw4 $dfw5
$TMp1
$MASK2D
$FMODE
$VARMD
$SATinDayNV18p1
$WTSDayNV18p3
$WTSDayNV18p2
$WTSDayNV18p1
$WTSDayNV18  
$WTSDayNV18m1
$ANALDayNV18p1
$SATCORDayNV18p1
inxEOF
cat eotcor4-dayNV18
#
cat <<inxEOF> eotcor4-nteNV18
$modes $nuse
$dfw1 $dfw2 $dfw3 $dfw4 $dfw5
$TMp1
$MASK2D
$FMODE
$VARMD
$SATinNteNV18p1
$WTSNteNV18p3
$WTSNteNV18p2
$WTSNteNV18p1
$WTSNteNV18  
$WTSNteNV18m1
$ANALNteNV18p1
$SATCORNteNV18p1
inxEOF
cat eotcor4-nteNV18   
#
$work/eotcor4.x  -Wl,-T <eotcor4-dayNV17 
stopcode=$?  
echo 'eotcor4 Navy17-day: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy17-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotcor4.f Navy17-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy17-day data error'
  exit
fi 


$work/eotcor4.x  -Wl,-T <eotcor4-nteNV17 
stopcode=$?  
echo 'eotcor4 Navy17-nte: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy17-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotcor4.f Navy17-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy17-nte data error'
  exit
fi 



$work/eotcor4.x  -Wl,-T <eotcor4-dayNV18 
stopcode=$?  
echo 'eotcor4 Navy18-day: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy18-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotcor4.f Navy18-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy18-day data error'
  exit
fi 


$work/eotcor4.x  -Wl,-T <eotcor4-nteNV18 
stopcode=$?  
echo 'eotcor4 Navy18-nte: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy18-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotcor4.f Navy18-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy18-nte data error'
  exit
fi 
#
#
# end EOT bias correction day & night
#
echo EOT BIAS CORRECTION DONE
#
# begin OI analysis
#
  echo 'compute OI for date ' $TM
#
FGSST=/raid2/sstday/$YEARm1/eotanal/navy1718-finv2/sst4-navy1718-eot-finv2.$TMm1
OISST=/raid2/sstday/$YEAR/eotanal/navy1718-finv2/sst4-navy1718-eot-finv2.$TM
#
BUOYNSR=/raid2/sstday/stats/buoy4sm-nsr-stat-v2
SHIPNSR=/raid2/sstday/stats/ship4sm-nsr-stat-v2
SATNSRDayNV17=/raid2/sstday/stats/day-path4sm-nsr-stat-v2
SATNSRNteNV17=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2
SATNSRDayNV18=/raid2/sstday/stats/day-path4sm-nsr-stat-v2
SATNSRNteNV18=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2
ICENSR=/raid2/sstday/stats/cice4sm-nsr-stat-v2 
#
BUOYNSRp1=/raid2/sstday/stats/buoy4sm-nsr-stat-v2-scaled
SHIPNSRp1=/raid2/sstday/stats/ship4sm-nsr-stat-v2-scaled
SATNSRDayNV17p1=/raid2/sstday/stats/day-path4sm-nsr-stat-v2-scaled
SATNSRNteNV17p1=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2-scaled
SATNSRDayNV18p1=/raid2/sstday/stats/day-path4sm-nsr-stat-v2-scaled
SATNSRNteNV18p1=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2-scaled
ICENSRp1=/raid2/sstday/stats/cice4sm-nsr-stat-v2-scaled 
#
BUOYNSRm1=/raid2/sstday/stats/buoy4sm-nsr-stat-v2-scaled
SHIPNSRm1=/raid2/sstday/stats/ship4sm-nsr-stat-v2-scaled
SATNSRDayNV17m1=/raid2/sstday/stats/day-path4sm-nsr-stat-v2-scaled
SATNSRNteNV17m1=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2-scaled
SATNSRDayNV18m1=/raid2/sstday/stats/day-path4sm-nsr-stat-v2-scaled
SATNSRNteNV18m1=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2-scaled
ICENSRm1=/raid2/sstday/stats/cice4sm-nsr-stat-v2-scaled 
#
BUOYDAT=/raid2/sstday/$YEAR/sobs/coad/buoy/buoy.$TM
SHIPDAT=/raid2/sstday/$YEAR/cobs/coad/ship/ship.$TM
BUOYDATm1=/raid2/sstday/$YEARm1/sobs/coad/buoy/buoy.$TMm1
SHIPDATm1=/raid2/sstday/$YEARm1/cobs/coad/ship/ship.$TMm1
BUOYDATp1=/raid2/sstday/$YEARp1/sobs/coad/buoy/buoy.$TMp1
SHIPDATp1=/raid2/sstday/$YEARp1/cobs/coad/ship/ship.$TMp1
if [ $TM -lt 20050101 ]
then
  ICEDAT=/raid2/sstday/$YEAR/sobs/gsfc/ice2sst.$TM
else
  ICEDAT=/raid2/sstday/$YEAR/sobs/ncep/icesst/icesst.$TM
fi
if [ $TMp1 -lt 20050101 ]
then
  ICEDATp1=/raid2/sstday/$YEARp1/sobs/gsfc/ice2sst.$TMp1
else
  ICEDATp1=/raid2/sstday/$YEARp1/sobs/ncep/icesst/icesst.$TMp1
fi
if [ $TMm1 -lt 20050101 ]
then
  ICEDATm1=/raid2/sstday/$YEARm1/sobs/gsfc/ice2sst.$TMm1
else
  ICEDATm1=/raid2/sstday/$YEARm1/sobs/ncep/icesst/icesst.$TMm1
fi
#
#
#
#  1st OIsst4 input record is the title
#  2nd OIsst4 input record is the date
#  The 3rd OISST4 input record is 4 parameters: 
#     $rmax $nmax $ifil $rej $nbias $nsat
#  All remaining records are input and output file names which must be in order
#  NOTE: OISST4 can have a large number of input file data sets
#  The 1st file name is the correlation scales
#  The 2nd file name is the estimated first guess variance error
#  The 3rd file name is the correlation correction due to use of fg 
#      from previous analysis instead of anomaly. Now set to 1
#  The 4th file name is the first guess
#  The 5th file name is the land/sea mask
#  The 6th file name is the climatology (weekly OI 1971-2000 base period)
#  The 7th file name is the output OI: this is the only output file
#  The 8th file name is the residual bias variance
#  Next nbias files follow: nbias may be 0
#     Each of these files is from the EOT bias correction with EOT bias error
#  Then in file namepairs until end of data: 
#    Odd file name:  "SST noise to signal ratio (std dev)" 
#    Even file name: "SST data file"
#
echo " "
echo "title"
echo "TM"
echo "rmax nmax ifil rej"
echo " "
cat <<inxEOF> oiparm 
$title
$TM
$rmax $nmax $ifil $rej $nbias $nsat  $iwarn  
$CORXY
$FGVAR
$RFAC
$FGSST
$MASK
$CLIM
$OISST
$RESID
$ANALDayNV17         
$ANALNteNV17        
$ANALDayNV18        
$ANALNteNV18       
$BUOYNSR
$BUOYDAT
$SHIPNSR
$SHIPDAT
$SATNSRDayNV17
$SATCORDayNV17
$SATNSRNteNV17
$SATCORNteNV17
$SATNSRDayNV18
$SATCORDayNV18
$SATNSRNteNV18
$SATCORNteNV18
$ICENSR 
$ICEDAT
$BUOYNSRp1
$BUOYDATp1
$SHIPNSRp1
$SHIPDATp1
$SATNSRDayNV17p1
$SATCORDayNV17p1
$SATNSRNteNV17p1
$SATCORNteNV17p1
$SATNSRDayNV18p1
$SATCORDayNV18p1
$SATNSRNteNV18p1
$SATCORNteNV18p1
$ICENSRp1 
$ICEDATp1
$BUOYNSRm1
$BUOYDATm1
$SHIPNSRm1
$SHIPDATm1
$SATNSRDayNV17m1
$SATCORDayNV17m1
$SATNSRNteNV17m1
$SATCORNteNV17m1
$SATNSRDayNV18m1
$SATCORDayNV18m1
$SATNSRNteNV18m1
$SATCORNteNV18m1
$ICENSRm1 
$ICEDATm1
inxEOF
cat oiparm
$work/oi.x  -Wl,-T <oiparm
  stopcode=$? 
  echo 'oilp: call exit ' $stopcode
  
  if [ $stopcode -eq 10 ]
  then
    echo 'ERROR IN OI $stopcode' 
#    $FTN2/oi.x  -Wl,-T <oiparm > sst4_bias_amsr.out.$TMmid  
#    cat sst4_bias_amsr.out.$TMmid
  fi
  
if [ $stopcode -eq 100 ]
then
#    $FTN2/oi.x  -Wl,-T <oiparm > sst4_bias_amsr.out.$TMmid  
#    cat sst4_bias_amsr.out.$TMmid
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi.f  data error'
  exit
fi 

# end OI analysis

echo NAVY17 NAVY18 FINV2 OI ANALYSIS DONE

echo "************** end time for run OI code =" `date '+%T'`



# write out the successful run date file

#rm oi_finv2.txt
echo $TMmid > /raid2/cliu/sstday/script/oi_finv2.txt

#cat <<inxEOF> /raid2/cliu/sstday/script/oi_finv2.txt
#$TMmid
#inxEOF


rm  /raid2/cliu/sstday/script/oi_finv2_ccdate.txt
# echo the month through a sed script that will assign a month abbreviation
# to the variable $mon for the 2-digit month
ccmon=`echo $immid|sed -e "
     s/01/Jan/
     s/02/Feb/
     s/03/Mar/
     s/04/Apr/
     s/05/May/
     s/06/Jun/
     s/07/Jul/
     s/08/Aug/
     s/09/Sep/
     s/10/Oct/
     s/11/Nov/
     s/12/Dec/"`
     
echo $ccmon
# convert letters to CAPITAL
ccmon=`echo $ccmon|tr [a-z] [A-Z]`
echo $ccmon
echo  $idmid $ccmon $iyrmid> /raid2/cliu/sstday/script/oi_finv2_ccdate.txt


export DISPLAY=cliu:0

cd /raid2/cliu/sstday/grads/


/raid/cliu/grads-bin/gradsc -blc "/raid2/cliu/sstday/grads/navy1718_finv2_total.gs"
#scp navy-sst-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-ss.gif
#scp navy-sst-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-s-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-sst-s-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-sst-s-$TMmid.gif

#scp navy-sst-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-bb.gif
#scp navy-sst-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-b-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-sst-b-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-sst-b-$TMmid.gif


/raid/cliu/grads-bin/gradsc -blc "/raid2/cliu/sstday/grads/navy1718_finv2_anom.gs"
#scp navy-anom-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-ss.gif
#scp navy-anom-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-s-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-anom-s-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-anom-s-$TMmid.gif

#scp navy-anom-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-bb.gif
#scp navy-anom-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-b-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-anom-b-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-anom-b-$TMmid.gif


#mv /raid2/cliu/sstday/grads/navy1718*.prt /raid2/sstday/oper/$iyrmid/
rm /raid2/cliu/sstday/grads/navy1718*.prt

# sync file to the lwf
#ssh mesohigh sudo /usr/local/bin/syncall /www/html/img/climate/research/sstday/navy-sst-ss.gif >> /tmp/daily-oisst.sync
#ssh mesohigh sudo /usr/local/bin/syncall /www/html/img/climate/research/sstday/navy-sst-bb.gif >> /tmp/daily-oisst.sync
#ssh mesohigh sudo /usr/local/bin/syncall /www/html/img/climate/research/sstday/navy-anom-ss.gif >> /tmp/daily-oisst.sync
#ssh mesohigh sudo /usr/local/bin/syncall /www/html/img/climate/research/sstday/navy-anom-bb.gif >> /tmp/daily-oisst.sync


iyrmid0=$iyrmid

#find the next day.
  
  TMg=$TMmid
  TMmid=`sh /raid2/cliu/sstday/script/finddate.sh $TMg d+1`
  
  iyrmid=`expr $TMmid | cut -c1-4`
  iyrmid22=`expr $TMmid | cut -c3-4`
  immid=`expr $TMmid | cut -c5-6`
  idmid=`expr $TMmid | cut -c7-8`

echo $iyrmid
echo $immid
echo $idmid

echo "************** end time for run grads map =" `date '+%T'`

cd /raid2/cliu/sstday/script/
 
done


# generate NOMADS NetCDF


lf95 -o /raid2/cliu/sstday/script/oi_netcdf_navy_finv2_NOMADS.x /raid2/cliu/sstday/ftn/oi_netcdf_navy_finv2_NOMADS.f -M$NFf90/src/f90 -L$NFf90/lib -lnetcdf 
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit

cat << netcdfEOF> netcdf.parm
$iyrs $imos $idas $iyre $imoe $idae
$curryear $currmon $today,$hour,$min
netcdfEOF
cat netcdf.parm

 /raid2/cliu/sstday/script/oi_netcdf_navy_finv2_NOMADS.x -Wl,-T <netcdf.parm
echo 'oi_netcdf_navy_finv2_NOMADS.x : call exit ' $stopcode

if [ $stopcode -eq 10 ]
then

    echo 'oi_netcdf_navy_finv2_NOMADS.x' $stopcode
fi 

if [ $stopcode -eq 100 ]
then
     echo 'oi_netcdf_navy_finv2_NOMADS.x' $stopcode

  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi_netcdf_navy_finv2_NOMADS.f data error'
  exit
fi 

echo "************** end time for run NOMADS NetCDF =" `date '+%T'`

# generate GHRSST NetCDF

#rm /raid2/cliu/sstday/script/oi_netcdf_navy_finv2_GHRSST.x
lf95 -o /raid2/cliu/sstday/script/oi_netcdf_navy_finv2_GHRSST.x /raid2/cliu/sstday/ftn/oi_netcdf_navy_finv2_GHRSST.f -M$NFf90/src/f90 -L$NFf90/lib -lnetcdf 
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit

rm fr_navy_finv2.x
lf95 -o /raid2/cliu/sstday/script/fr_navy_finv2.x /raid2/cliu/sstday/ftn/fr_navy_finv2.f
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit     

cat << netcdfEOF> netcdf_ghrsst.parm
$iyrs $imos $idas $iyre $imoe $idae
$curryear $currmon $today
netcdfEOF
cat netcdf_ghrsst.parm

 /raid2/cliu/sstday/script/oi_netcdf_navy_finv2_GHRSST.x -Wl,-T <netcdf_ghrsst.parm
   stopcode=$?  
echo 'oi_netcdf_navy_finv2_GHRSST.x : call exit ' $stopcode

if [ $stopcode -eq 10 ]
then

    echo 'oi_netcdf_navy_finv2_GHRSST.x' $stopcode

fi 

if [ $stopcode -eq 100 ]
then
echo 'oi_netcdf_navy_finv2_GHRSST.x' $stopcode
exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi_netcdf_navy_finv2_GHRSST.f data error'
  exit
fi 

#Generate FR file
 /raid2/cliu/sstday/script/fr_navy_finv2.x -Wl,-T <netcdf_ghrsst.parm 
   stopcode=$?  
echo 'fr_navy_finv2.x : call exit ' $stopcode

if [ $stopcode -eq 10 ]
then

    echo 'fr_navy_finv2.x' $stopcode
#    cat /raid2/cliu/sstday/script/output/fr_navy_finv2.$iyrs$imos$idas'_'$iyre$imoe$idae
fi 

if [ $stopcode -eq 100 ]
then
echo 'fr_navy_finv2.x' $stopcode
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: fr_navy_finv2.f data error'
  exit
fi 

echo "************** end time for run GHRSST NetCDF =" `date '+%T'`


# scp NetCDF to eclipse

TM=$iyrs$imos$idas
TMe=$iyre$imoe$idae

while [ "$TM" -le "$TMe" ]
do

scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc eclipse-d:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc eclipse-d2:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz eclipse-d:/raid/ftp/pub/OI-daily-v2/NetCDF-uncompress/$iyrs/AVHRR

CreateMNF /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc
scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.mnf eclipse-d:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR

# sftp to gulp2 Archive

rm ftp_archive

echo "open gulp2.ncdc.noaa.gov" >> ftp_archive
echo "user anonymous Chunying.Liu@noaa.gov" >> ftp_archive
echo "lcd /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2" >> ftp_archive
echo "cd /pub/upload/Ingest/OISST/avhrr_only/$iyrs " >> ftp_archive
echo "put avhrr-only-v2.$TM.nc" >> ftp_archive
echo "put avhrr-only-v2.$TM.nc.mnf" >> ftp_archive
echo "quit" < ftp_archive 

ftp -n -v -i < ftp_archive



if [ -f  /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz ]
then 
rm /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz
fi 

gzip /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc
scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz eclipse-d:/san/ftp/pub/oisst/NetCDF/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz eclipse-d2:/san/ftp/pub/oisst/NetCDF/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_finv2/avhrr-only-v2.$TM.nc.gz eclipse-d:/raid/ftp/pub/OI-daily-v2/NetCDF/$iyrs/AVHRR

if [ -f  /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM.gz ]
then 
rm /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM.gz
fi 

gzip /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM
scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM.gz eclipse-d:/san/ftp/pub/oisst/IEEE/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM.gz eclipse-d2:/san/ftp/pub/oisst/IEEE/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_finv2/avhrr-only-v2.$TM.gz eclipse-d:/raid/ftp/pub/OI-daily-v2/IEEE/$iyrs/AVHRR

 
#scp GHRSST NetCDF

if [ -f  /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2 ]
then 
rm /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2
fi 

bzip2 /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc

cut -c '2-' /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml > junk9
mv junk9 /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml

md5sum /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml>/raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5

md5sum /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2>/raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5

# sftp to melia

 rm ftp_melia

# echo "user sftp-ghrsst cyclops-12" > ftp_melia
 echo "cd NCDC/tmp" >> ftp_melia
# echo "bin" >> ftp_melia
# echo "prompt" >> ftp_melia
 echo "lcd /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_finv2" >> ftp_melia
 echo "put $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2" >> ftp_melia
 echo "put FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml" >> ftp_melia
 echo "put FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5" >> ftp_melia
 echo "put $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5" >> ftp_melia
 
 echo "rename $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2 ../$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2" >> ftp_melia
 echo "rename FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml ../FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml" >> ftp_melia
 echo "rename FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5 ../FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5" >> ftp_melia
 echo "rename $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5 ../$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5" >> ftp_melia
 

# echo "quit" >> ftp_melia

sftp sftp-ghrsst@melia.jpl.nasa.gov < ftp_melia 


#find the next day.
  
TM=`sh /home/cliu/shell_lib/finddate.sh $TM d+1`

iyrs=`expr $TM | cut -c1-4`

echo "************** end time for scp NetCDF to eclipse =" `date '+%T'`
  
done 

echo 'NetCDF were generated and ftp to melia'





