#! /bin/sh
# /raid2/cliu/sstdat/script/navy1718-intv2-oisst4-oper.sh

# run both bias and nobias OI in the same code
# set -x # turns on echo  for script
# set +x # turns off echo for script

# modified from navy-oisst4_eotbias+nobias_oper.sh
# 1. read in 1/2 ice, convert to 1/4 ice. 
#    then directly convert to sst using ncep_ice2sst.f
# 2. add err in satellite bias correction.

# Chunying Liu  finished in July 2008

 
. /usr/local/lf9562/bash_setup   # setup the Fortran lib for cron job
GASCRP='/home/cliu/grads_lib'
PATH=$PATH:/home/cliu/netcdf/netcdf-3.6.0-p1/f90/bin
export PATH GADDIR GASCRP
export NFf90=/home/cliu/netcdf/netcdf-3.6.0-p1/f90
ulimit -s unlimited
umask 002

CreateMNF() {
 local CMErr='none'
 if [ -s $1 ];then
   local MD5Ar=( $(md5sum --binary $1 |tr -s ' ' |tr -d '\*') )
   if [ ${#MD5Ar[@]} -eq 2 ];then
     local FSZ=$(find ${1%/*}"/" -name "${1##*/}" -printf "%s")
     if [ ${#FSZ} -gt 0 ];then
       echo ${1##*/},${MD5Ar[0]},$FSZ > $1".mnf"
     else
       CMErr="FileSizeError"
     fi
   else
     CMErr="ChkSumError"
   fi
 else
   CMErr="FileNOTFound"
 fi
 if [ $CMErr != 'none' ];then
   echo CreateMNF Failed: $CMErr
 fi
}

echo 'NAVY EOT BIAS CORRECTION NOAA19 METOP INTV2 OI RUN '

#echo "Script run today to produce sobs for yesterday"

curryear=`date '+%Y'`
currmon=`date '+%m'`
today=`date '+%d'`
hour=`date '+%H'`
min=`date '+%M'`
echo $curryear,$currmon,$today,$hour,$min


TMtoday=$curryear$currmon$today
#echo $TMtoday

#TMtoday=20090209

# TMstop is the last anylysis day, it is one days ago when using NCEP 1-day delay in situ data
# or one day ago when using NCDC in situ data
   
TMstop=`sh /raid/cliu/shell_lib/finddate.sh $TMtoday d-1`
echo attempt to run untill $TMstop
imstop=`expr $TMstop | cut -c5-6`

#get parm for NetCDF
iyre=`expr $TMstop | cut -c1-4`
imoe=`expr $TMstop | cut -c5-6`
idae=`expr $TMstop | cut -c7-8`

# read in from last run's output file to find out the analysis date which has a successful run

TMlast=`cat /raid2/cliu/sstday/script/oi_intv2.txt`
echo 'the last successful run date:'$TMlast


if [ "$TMlast" -ge "$TMstop" ]
then
echo Today is $TMtoday. The input data only allow OI run utill $TMstop.
echo $TMstop already run successful.
exit
fi

# the start date of this run is 
TMmid=`sh /raid/cliu/shell_lib/finddate.sh $TMlast d+1`
#echo start run date: $TMmid

# as if it is a historic run

echo ' start date' $TMmid
echo ' end   date' $TMstop


#get parm for NetCDF
iyrs=`expr $TMmid | cut -c1-4`
imos=`expr $TMmid | cut -c5-6`
idas=`expr $TMmid | cut -c7-8`


# when run navy1718-intv2-oisst4-oper.sh inside navy1718-intv2-oisst4-data-oper.sh
# it is always run one day at a time.
# the end day should equal the start day

iyre=`expr $TMmid | cut -c1-4`
imoe=`expr $TMmid | cut -c5-6`
idae=`expr $TMmid | cut -c7-8`

echo 'parameters for NetCDF run:' $iyrs$imos$idas'_'$iyre$imoe$idae

iyrmid=`expr $TMmid | cut -c1-4`
immid=`expr $TMmid | cut -c5-6`
idmid=`expr $TMmid | cut -c7-8`

echo $iyrmid
echo $immid
echo $idmid

iyrmid0=0000


FTN=/raid2/cliu/sstday/ftn4              # FORTRAN CODES
work=/raid2/sstday/$iyrs/work/eotanal/navy1718-intv2/       # WORKING_DIRECTORY
DATA=/raid2/sstday/script                  # Script directory
#
FMODE=/raid2/sstday/stats/eot6.damp-zero.ev130.ano.dat   # EOT modes file (filled)
MASK2D=/raid2/sstday/clim/lstags.twodeg.dat      # EOT Land/SEA FILE
CLIM2D=/raid2/sstday/clim/clim.71.00.gdat        # EOT Climate FILE
VARMD=/raid2/sstday/stats/var-mode    # Variance of each modes
#
RESID=/raid2/sstday/stats/residual-stat-v2
CORXY=/raid2/sstday/stats/cor4sm-stat-v2
FGVAR=/raid2/sstday/stats/path-incr-var-stat-v2
RFAC=/raid2/sstday/stats/error-cor-stat-v2
MASK=/raid2/sstday/clim/quarter-mask-extend
CLIM=/raid2/sstday/clim/oiclm4.mon
#
#
# Initial data for ship
globc=0.14				# global ship bias adjustment
#
#
# Initial data for EOT weights
minz=750       		# minimum number of smoothed zonal points
njj=10			# number of latitude points for zonal smoothing  
minob=1	        	# minimum number of obs used in zonal average
ioff=1			# number of longitude boxes smoothed for zonal sub
joff=1   		# number of latitude boxes smoothed for zonal sub
ndays=7                 # number of days used
drej=5.			# data REJECT LIMIT for ABSOLUTE SST increment 
crit=0.25	        # critical data/total area ratio 
modes=130	        # number of modes used <131
nby=7			# number of ship obs = 1 buoy obs 
nsh=1			# number of buoy obs = 1 
nst=1			# number of sat obs = 1 
yrbuoy=15		# character count of buoy first number of year
yrship=15		# character count of ship first number of year
yrsat=15		# character count of sat first number of year
daybuoy=40		# character count of buoy first number of date
dayship=40		# character count of ship first number of date
daysat=44		# character count of sat first number of data
#
# Initial data for EOT corrections
nuse=1                  # number of weights used (1, 3, or 5, default is 1) 
dfw1=1.0                # factor to smooth the weights: range 0 to 1    
#

rmax=400.	# maximum x or y distance (km) over which obs are used.
nmax=22		# maximum number of obs are used. Must be <201
ifil=1		# number of times 1-2-1 smoothing is done; <1 no smoothing 
rej=5.		# bias REJECT LIMIT for ABSOLUTE super obs increment
nbias=4		# number of files to read of EOT bias estimates
nsat=1		# number independent satellite bias data sets 
iwarn=20	# Percentage of satellite data: if lower warning message printed 


echo 'working directory '$work
[ -d $work ] || mkdir -p $work
cd $work
# clean up any old source or  executable files
touch dum.f
touch dum.x
rm *.f
rm *.x
#

# Set up and Compile ship bias correction Analysis Code
cp $FTN/shipbias4-col.f shipbias4.f 
#
     echo 'COMPILE shipbias4.f'
#     lf95  --chk -g --trace --info -o shipbias4.x shipbias4.f 
     lf95  -o /raid2/cliu/sstday/ftn4/shipbias4.x shipbias4.f 
     err=$?
     [ $err -ne 0 ] && exit

# Set up and Compile eot weight bias correction Analysis Code
cat $FTN/eotbias-wt4-col.f $FTN/lib/date.f> eotbias-wt4.f
#
     echo 'COMPILE eotbias-wt4-col.f'
#     lf95  --chk -g --trace --info -o eotwt4.x eotbias-wt4.f 
     lf95  -o eotwt4.x eotbias-wt4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
#
# Set up and Compile eot bias correction Analysis Code
cp $FTN/eotbias-cor4-col.f eotbias-cor4.f
#
     echo 'COMPILE eotbias-cor4.f'
#     lf95  --chk -g --trace --info -o eotcor4.x eotbias-cor4.f 
     lf95  -o eotcor4.x eotbias-cor4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
# Set up and Compile daily OI Analysis Code
cat $FTN/oisst4-col.f $FTN/lib/sposl.f $FTN/lib/spoco.f $FTN/lib/date.f> oi.f
#cat $FTN/biasbld.f $FTN/weaver_f90.f > bias.f
#
     echo 'COMPILE oisst4-col.f'
     lf95  -o oi.x oi.f 
     err=$?
     [ $err -ne 0 ] && exit
#

while [ "$TMmid" -le "$TMstop" ]
do

echo 'Analysis date ' $TMmid

TMg=`sh /home/cliu/shell_lib/finddate.sh $TMmid d-1`
echo 'First guess EOT date ' $TMg
YEARg=`echo $TMg | cut -c 1-4`

#----------------------------------------------------------------------------------

YEARs=`echo $TMmid | cut -c 1-4`
echo $YEARs

#
# Initial data for OI

  title='Daily-OI-V2, Interim, Data (Ship, Buoy, AVHRR: NOAA19, METOP, NCEP-ice)' 


  TM=$TMmids
#

if [ "$iyrmid" -ne "$iyrmid0" ]
then
work=/raid2/sstday/$YEARs/work/eotanal/navy1718-intv2/
echo 'working directory '$work
[ -d $work ] || mkdir -p $work
cd $work


# Set up and Compile ship bias correction Analysis Code
cp $FTN/shipbias4-col.f shipbias4.f 
#
     echo 'COMPILE shipbias4.f'
#     lf95  --chk -g --trace --info -o shipbias4.x shipbias4.f 
     lf95  -o /raid2/cliu/sstday/ftn4/shipbias4.x shipbias4.f 
     err=$?
     [ $err -ne 0 ] && exit

# Set up and Compile eot weight bias correction Analysis Code
cat $FTN/eotbias-wt4-col.f $FTN/lib/date.f> eotbias-wt4.f
#
     echo 'COMPILE eotbias-wt4-col.f'
#     lf95  --chk -g --trace --info -o eotwt4.x eotbias-wt4.f 
     lf95  -o eotwt4.x eotbias-wt4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
#
# Set up and Compile eot bias correction Analysis Code
cp $FTN/eotbias-cor4-col.f eotbias-cor4.f
#
     echo 'COMPILE eotbias-cor4.f'
#     lf95  --chk -g --trace --info -o eotcor4.x eotbias-cor4.f 
     lf95  -o eotcor4.x eotbias-cor4.f 
     err=$?
     [ $err -ne 0 ] && exit
#
# Set up and Compile daily OI Analysis Code
cat $FTN/oisst4-col.f $FTN/lib/sposl.f $FTN/lib/spoco.f $FTN/lib/date.f> oi.f
#cat $FTN/biasbld.f $FTN/weaver_f90.f > bias.f
#
     echo 'COMPILE oisst4-col.f'
     lf95  -o oi.x oi.f 
     err=$?
     [ $err -ne 0 ] && exit
#


fi

  echo 'compute EOT for date ' $TMmid
  YEAR=`echo $TMmid | cut -c 1-4`
#
#  start ship bias correction
#
SHIPORG=/raid2/sstday/$YEAR/sobs/coad/ship/ship.$TMmid
SHIPCOR=/raid2/sstday/$YEAR/cobs/coad/ship/ship.$TMmid
#
#  The 1st eship bias4 input record 1 parameter: globc
#  All remaining records are input and output file names which must be in order
#  The 1st file name is the input daily ship data 
#  The 2nd file name is the output corrected daily ship data 
#
echo "globc"
cat <<inxEOF> shipbias4.inp
$globc
$SHIPORG
$SHIPCOR
inxEOF
  cat shipbias4.inp
/raid2/cliu/sstday/ftn4/shipbias4.x  -Wl,-T <shipbias4.inp 
stopcode=$?  
echo 'shipbias4: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL: shipbias4.f completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING:  IN shipbias4.f' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: shipbias4.f data error'
  exit
fi 

#
# end ship bias correction
#
# begin EOT weights for bias correction day & night
#
WTSDayNV17=/raid2/sstday/$YEAR/eotwt-intv2/navy-err/dsat17/wtday17.$TMmid
WTSNteNV17=/raid2/sstday/$YEAR/eotwt-intv2/navy-err/nsat17/wtnte17.$TMmid
WTSDayNV18=/raid2/sstday/$YEAR/eotwt-intv2/navy-err/dsat18/wtday18.$TMmid
WTSNteNV18=/raid2/sstday/$YEAR/eotwt-intv2/navy-err/nsat18/wtnte18.$TMmid
#
BUOY=/raid2/sstday/yyyy/sobs/coad/buoy/buoy.dddddddd
#    12345678901234567890123456789012345678901234567890
#             1         2         3         4
SHIP=/raid2/sstday/yyyy/cobs/coad/ship/ship.dddddddd
#    12345678901234567890123456789012345678901234567890
#             1         2         3         4
SATDayNV17=/raid2/sstday/yyyy/sobs/navy/dsat17/dsat17.dddddddd
SATNteNV17=/raid2/sstday/yyyy/sobs/navy/nsat17/nsat17.dddddddd
SATDayNV18=/raid2/sstday/yyyy/sobs/navy/dsat18/dsat18.dddddddd
SATNteNV18=/raid2/sstday/yyyy/sobs/navy/nsat18/nsat18.dddddddd
#         12345678901234567890123456789012345678901234567890
#                  1         2         3         4
#
#  The 1st eotwt4 input record is 5 minz,njj,minob,ioff,joff
#  The 2nd eotwt4 input record is 5 parameters: nby,nsh,nst,ndays,nmodes
#  The 3rd record is 3 parameters: yrbuoy yrship yrsat
#  The 4th record is 3 parameters: daybuoy dayship daysat
#  The 5th record is 3 paramters: drej crit
#  The 6th input record is the date
#  All remaining records are input and output file names which must be in order
#  The 1st file name is the two-degree land/sea mask
#  The 2nd file name is the monthly climate (1-deg)
#  The 3rd file name is the input EOT modes (filled over land with 0)
#  The 4th file name is the analyzed weights (output) 
#  The 5th file name is the input buoy data 
#  The 6th file name is the input ship data 
#  The 7th file name is the input satellite data
#  Multitple dates are read in and the complete file names
#    for these last 3 files are computed in the fortran code
#
#  Note all satellite fields, weights differ for day and night
#
echo " "
echo "minz njj minob ioff joff"
echo "nby nsh nst ndays modes"
echo "yrbuoy yrship yrsat"
echo "daybuoy dayship daysat"
echo "drej crit"
echo "TM"
echo " "
cat <<inxEOF> eotwt4-dayNV17
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit
$TMmid
$MASK2D
$CLIM2D
$FMODE
$WTSDayNV17
$BUOY
$SHIP
$SATDayNV17
inxEOF
cat eotwt4-dayNV17
#
cat <<inxEOF> eotwt4-nteNV17
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit
$TMmid
$MASK2D
$CLIM2D
$FMODE
$WTSNteNV17
$BUOY
$SHIP
$SATNteNV17
inxEOF
cat eotwt4-nteNV17   
#
cat <<inxEOF> eotwt4-dayNV18
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit 
$TMmid
$MASK2D
$CLIM2D
$FMODE
$WTSDayNV18
$BUOY
$SHIP
$SATDayNV18
inxEOF
cat eotwt4-dayNV18
#
cat <<inxEOF> eotwt4-nteNV18
$minz $njj $minob $ioff $joff
$nby $nsh $nst $ndays $modes
$yrbuoy $yrship $yrsat
$daybuoy $dayship $daysat
$drej $crit 
$TMmid
$MASK2D
$CLIM2D
$FMODE
$WTSNteNV18
$BUOY
$SHIP
$SATNteNV18
inxEOF
cat eotwt4-nteNV18   
#

./eotwt4.x  -Wl,-T <eotwt4-dayNV17 
stopcode=$?  
echo 'eotwt4-dayNV17: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY17-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY17-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY17-day data error'
  exit
fi 


./eotwt4.x  -Wl,-T <eotwt4-nteNV17 
stopcode=$?  
echo 'eotwt4-nteNV17: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY17-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'ERROR IN eotwt4.f NAVY17-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY17-nte data error'
  exit
fi 


./eotwt4.x  -Wl,-T <eotwt4-dayNV18 
stopcode=$?  
echo 'eotwt4-dayNV18: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY18-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING: ERROR IN eotwt4.f NAVY18-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY18-day data error'
  exit
fi 




./eotwt4.x  -Wl,-T <eotwt4-nteNV18 
stopcode=$?  
echo 'eotwt4-nteNV18: call exit ' $stopcode

if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotwt4.f NAVY18-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING! ERROR IN eotwt4.f NAVY18-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotwt4.f  NAVY18-nte data error'
  exit
fi 


# end EOT Weight CORRECTION DONE
#
echo EOT Weight CORRECTION DONE
#
# begin EOT bias correction day & night
#
ANALDayNV17=/raid2/sstday/$YEAR/eotcor-intv2/navy-err/dsat17/dsat17.$TMmid         
ANALNteNV17=/raid2/sstday/$YEAR/eotcor-intv2/navy-err/nsat17/nsat17.$TMmid         
ANALDayNV18=/raid2/sstday/$YEAR/eotcor-intv2/navy-err/dsat18/dsat18.$TMmid         
ANALNteNV18=/raid2/sstday/$YEAR/eotcor-intv2/navy-err/nsat18/nsat18.$TMmid         
SATCORDayNV17=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/dsat17/dsat17.$TMmid
SATCORNteNV17=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/nsat17/nsat17.$TMmid
SATCORDayNV18=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/dsat18/dsat18.$TMmid
SATCORNteNV18=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/nsat18/nsat18.$TMmid
SATinDayNV17=/raid2/sstday/$YEAR/sobs/navy/dsat17/dsat17.$TMmid
SATinNteNV17=/raid2/sstday/$YEAR/sobs/navy/nsat17/nsat17.$TMmid
SATinDayNV18=/raid2/sstday/$YEAR/sobs/navy/dsat18/dsat18.$TMmid
SATinNteNV18=/raid2/sstday/$YEAR/sobs/navy/nsat18/nsat18.$TMmid
#
#  The 1st eotbias-cor4 input record has 2 parameters: nmodes, nuse
#  The 2nd eotbias-cor4 input record depends on nuse and has 1-9 parameters: dwf1,dwf2,...
#  The next input record is the date: computed by script 8 digits
#  All remaining records are input and output file names which must be in order
#  The 1st file name is the two-degree land/sea mask
#  The 2nd file name is the input EOT modes (filled over land with 0)
#  The 3rd file name is the variance of each of the 130 modes
#  Nuse (1-9) now determines the number of files read. They will be weighted by dwf
#        The weighting smoothing factors are applied in order: dwf1, ...
#  The next file name is the input uncorrected satellite data
#  The next file name is the output bias error estimate
#  The final file name is the output bias corrected satellite data 
#
#  Note all satellite fields, weights and biases differ for day and night
#
echo " "
echo "modes nuse"
echo "dfw values"
echo "TM"
echo " "
cat <<inxEOF> eotcor4-dayNV17
$modes $nuse
$dfw1 
$TMmid
$MASK2D
$FMODE
$VARMD
$SATinDayNV17
$WTSDayNV17
$ANALDayNV17
$SATCORDayNV17
inxEOF
cat eotcor4-dayNV17
#
cat <<inxEOF> eotcor4-nteNV17
$modes $nuse
$dfw1 
$TMmid
$MASK2D
$FMODE
$VARMD
$SATinNteNV17
$WTSNteNV17
$ANALNteNV17
$SATCORNteNV17
inxEOF
cat eotcor4-nteNV17   
#
cat <<inxEOF> eotcor4-dayNV18
$modes $nuse
$dfw1 
$TMmid
$MASK2D
$FMODE
$VARMD
$SATinDayNV18
$WTSDayNV18
$ANALDayNV18
$SATCORDayNV18
inxEOF
cat eotcor4-dayNV18
#
cat <<inxEOF> eotcor4-nteNV18
$modes $nuse
$dfw1 
$TMmid
$MASK2D
$FMODE
$VARMD
$SATinNteNV18
$WTSNteNV18
$ANALNteNV18
$SATCORNteNV18
inxEOF
cat eotcor4-nteNV18   


./eotcor4.x  -Wl,-T <eotcor4-dayNV17 
stopcode=$?  
echo 'eotcor4 Navy17-day: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy17-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING: ERROR IN eotcor4.f Navy17-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy17-day data error'
  exit
fi 


./eotcor4.x  -Wl,-T <eotcor4-nteNV17 
stopcode=$?  
echo 'eotcor4 Navy17-nte: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy17-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING: ERROR IN eotcor4.f Navy17-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy17-nte data error'
  exit
fi 



./eotcor4.x  -Wl,-T <eotcor4-dayNV18 
stopcode=$?  
echo 'eotcor4 Navy18-day: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy18-day code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING: ERROR IN eotcor4.f Navy18-day' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy18-day data error'
  exit
fi 


./eotcor4.x  -Wl,-T <eotcor4-nteNV18 
stopcode=$?  
echo 'eotcor4 Navy18-nte: call exit ' $stopcode


if [ $stopcode -eq 1 ]
then
    echo 'GREEN-SUCCESSFUL! eotcor4.f Navy18-nte code completed'
fi

if [ $stopcode -eq 10 ]
then
    echo 'YELLOW-WARNING: ERROR IN eotcor4.f Navy18-nte' $stopcode
fi

if [ $stopcode -eq 100 ]
then
  exit
fi 

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: eotcor4.f  Navy18-nte data error'
  exit
fi 

#
#
# end EOT bias correction day & night
#
echo EOT BIAS CORRECTION DONE
#
# begin OI analysis
#
  echo 'compute OI for date ' $TMmid
  YEAR=`echo $TMmid | cut -c 1-4`
  echo 'First guess OI date ' $TMg
  YEARg=`echo $TMg | cut -c 1-4`
  TMp=`sh /home/cliu/shell_lib/finddate.sh $TMmid d+1`
  YEARp=`echo $TMmidp | cut -c 1-4`
  echo 'date for data 1-day in future' $TMmidp
  
#
FGSST=/raid2/sstday/$YEARg/eotanal/nv1718-intv2/sst4-nv1718-eot-intv2.$TMg
OISST=/raid2/sstday/$YEAR/eotanal/nv1718-intv2/sst4-nv1718-eot-intv2.$TMmid
#
BUOYNSR=/raid2/sstday/stats/buoy4sm-nsr-stat-v2
SHIPNSR=/raid2/sstday/stats/ship4sm-nsr-stat-v2
SATNSRDayNV17=/raid2/sstday/stats/day-path4sm-nsr-stat-v2
SATNSRNteNV17=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2
SATNSRDayNV18=/raid2/sstday/stats/day-path4sm-nsr-stat-v2
SATNSRNteNV18=/raid2/sstday/stats/nte-path4sm-nsr-stat-v2
ICENSR=/raid2/sstday/stats/cice4sm-nsr-stat-v2 
#
BUOYDAT=/raid2/sstday/$YEAR/sobs/coad/buoy/buoy.$TMmid
SHIPDAT=/raid2/sstday/$YEAR/cobs/coad/ship/ship.$TMmid
SATDATDayNV17=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/dsat17/dsat17.$TMmid
SATDATNteNV17=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/nsat17/nsat17.$TMmid
SATDATDayNV18=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/dsat18/dsat18.$TMmid
SATDATNteNV18=/raid2/sstday/$YEAR/cobs/eotcor-intv2/navy-err/nsat18/nsat18.$TMmid
if [ $TMmid -lt 20050101 ]
then
  ICEDAT=/raid2/sstday/$YEAR/sobs/gsfc/ice2sst.$TMmid
else
  ICEDAT=/raid2/sstday/$YEAR/sobs/ncep/icesst/icesst.$TMmid
fi
#
#
#
#  1st OIsst4 input record is the title
#  2nd OIsst4 input record is the date
#  The 3rd OISST4 input record is 4 parameters: 
#     $rmax $nmax $ifil $rej $nbias $nsat
#  All remaining records are input and output file names which must be in order
#  NOTE: OISST4 can have a large number of input file data sets
#  The 1st file name is the correlation scales
#  The 2nd file name is the estimated first guess variance error
#  The 3rd file name is the correlation correction due to use of fg 
#      from previous analysis instead of anomaly. Now set to 1
#  The 4th file name is the first guess
#  The 5th file name is the land/sea mask
#  The 6th file name is the climatology (weekly OI 1971-2000 base period)
#  The 7th file name is the output OI: this is the only output file
#  The 8th file name is the residual bias variance
#  Next nbias files follow: nbias may be 0
#     Each of these files is from the EOT bias correction with EOT bias error
#  Then in file namepairs until end of data: 
#    Odd file name:  "SST noise to signal ratio (std dev)" 
#    Even file name: "SST data file"
#
echo " "
echo "title"
echo "TM"
echo "rmax nmax ifil rej"
echo " "
cat <<inxEOF> oiparm 
$title
$TMmid
$rmax $nmax $ifil $rej $nbias $nsat  $iwarn  
$CORXY
$FGVAR
$RFAC
$FGSST
$MASK
$CLIM
$OISST
$RESID
$ANALDayNV17         
$ANALNteNV17        
$ANALDayNV18        
$ANALNteNV18       
$BUOYNSR
$BUOYDAT
$SHIPNSR
$SHIPDAT
$SATNSRDayNV17
$SATDATDayNV17
$SATNSRNteNV17
$SATDATNteNV17
$SATNSRDayNV18
$SATDATDayNV18
$SATNSRNteNV18
$SATDATNteNV18
$ICENSR 
$ICEDAT
inxEOF
cat oiparm
./oi.x  -Wl,-T <oiparm
  stopcode=$? 
  echo 'oilp: call exit ' $stopcode
  
  if [ $stopcode -eq 10 ]
  then
    echo 'ERROR IN OI $stopcode' 
#    $FTN2/oi.x  -Wl,-T <oiparm > sst4_bias_amsr.out.$TMmid  
#    cat sst4_bias_amsr.out.$TMmid
  fi
  
if [ $stopcode -eq 100 ]
then
#    $FTN2/oi.x  -Wl,-T <oiparm > sst4_bias_amsr.out.$TMmid  
#    cat sst4_bias_amsr.out.$TMmid
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi.f  data error'
  exit
fi 

# finish loop
#
# cat sst4.out.$TMmid
#
# end OI analysis

echo  NAVY17 NAVY18 INTV2 OI ANALYSIS DONE


echo "************** end time for run OI code =" `date '+%T'`


# write out the successful run date file
rm /raid2/cliu/sstday/script/oi_intv2.txt
#rm /raid2/cliu/sstday/script/oi_intv2_date.txt

echo $TMmid > /raid2/cliu/sstday/script/oi_intv2.txt
#echo $TMmid > /raid2/cliu/sstday/script/oi_intv2_date.txt

#cat <<inxEOF> /raid2/cliu/sstday/script/oi_intv2.txt
#$TMmid
#inxEOF


rm  /raid2/cliu/sstday/script/oi_intv2_ccdate.txt
# echo the month through a sed script that will assign a month abbreviation
# to the variable $mon for the 2-digit month
ccmon=`echo $immid|sed -e "
     s/01/Jan/
     s/02/Feb/
     s/03/Mar/
     s/04/Apr/
     s/05/May/
     s/06/Jun/
     s/07/Jul/
     s/08/Aug/
     s/09/Sep/
     s/10/Oct/
     s/11/Nov/
     s/12/Dec/"`
     
echo $ccmon
# convert letters to CAPITAL
ccmon=`echo $ccmon|tr [a-z] [A-Z]`
echo $ccmon
echo  $idmid $ccmon $iyrmid> /raid2/cliu/sstday/script/oi_intv2_ccdate.txt

#cat <<oiEOF > /raid2/cliu/sstday/script/oi_cdate.txt
#$today  $ccmon $curryear
#oiEOF

# make GraDs maps to compare ERSST and OI

# map1:  large and small total sst err eot
# map2:  large and small anomaly err eot


export DISPLAY=cliu:0

cd /raid2/cliu/sstday/grads/


/raid/cliu/grads-bin/gradsc -blc "/raid2/cliu/sstday/grads/navy1718_intv2_total.gs"
#scp navy-sst-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-ss.gif
#scp navy-sst-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-s-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-sst-s-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-sst-s-$TMmid.gif

#scp navy-sst-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-bb.gif
#scp navy-sst-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-sst-b-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-sst-b-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-sst-b-$TMmid.gif


/raid/cliu/grads-bin/gradsc -blc "/raid2/cliu/sstday/grads/navy1718_intv2_anom.gs"
#scp navy-anom-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-ss.gif
#scp navy-anom-s-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-s-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-anom-s-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-anom-s-$TMmid.gif

#scp navy-anom-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-bb.gif
#scp navy-anom-b-$idmid$ccmon$iyrmid.gif mesohigh:/www/html/img/climate/research/sstday/navy-anom-b-$TMmid.gif
mv /raid2/cliu/sstday/grads/navy-anom-b-$idmid$ccmon$iyrmid.gif /raid2/sstday/oper/$iyrmid/navy-anom-b-$TMmid.gif

rm /raid2/cliu/sstday/grads/navy1718*.prt

# FTP maps to NCDC ftp server ftp://ftp.ncdc.noaa.gov/pub/data/oisst/
rm ftp_oisst
 echo "open ftp0.ncdc.noaa.gov" >> ftp_oisst
 echo "user anonymous Chunying.Liu@noaa.gov" >> ftp_oisst
 echo "cd pub/data/oisst" >> ftp_oisst
 echo "del navy-sst-ss.gif" >> ftp_oisst
 echo "del navy-sst-bb.gif" >> ftp_oisst
 echo "del navy-anom-ss.gif" >> ftp_oisst
 echo "del navy-anom-bb.gif" >> ftp_oisst 
 echo "lcd /raid2/sstday/oper/$iyrmid" >> ftp_oisst
 echo "bin" >> ftp_oisst

 echo "put navy-sst-b-$TMmid.gif" >> ftp_oisst
# echo "del navy-anom-s-$TMmid.gif" >> ftp_oisst
# echo "del navy-anom-b-$TMmid.gif" >> ftp_oisst
 echo "put navy-anom-s-$TMmid.gif" >> ftp_oisst
 echo "put navy-anom-b-$TMmid.gif" >> ftp_oisst
 
 echo "put navy-sst-s-$TMmid.gif navy-sst-ss.gif" >> ftp_oisst
 echo "put navy-sst-b-$TMmid.gif navy-sst-bb.gif" >> ftp_oisst
 echo "put navy-anom-s-$TMmid.gif navy-anom-ss.gif" >> ftp_oisst
 echo "put navy-anom-b-$TMmid.gif navy-anom-bb.gif" >> ftp_oisst 
 echo "quit" >> ftp_oisst
 
ftp -n -v -i < ftp_oisst

iyrmid0=$iyrmid

#find the next day.
  
  TMg=$TMmid
  TMmid=`sh /home/cliu/shell_lib/finddate.sh $TMg d+1`
  
  iyrmid=`expr $TMmid | cut -c1-4`
  iyrmid22=`expr $TMmid | cut -c3-4`
  immid=`expr $TMmid | cut -c5-6`
  idmid=`expr $TMmid | cut -c7-8`

echo $iyrmid
echo $immid
echo $idmid

# when run navy1718-intv2-oisst4-oper.sh inside navy1718-intv2-oisst4-data-oper.sh
# it is always run one day at a time, then get the next day's data then run again
# so set stop day equal to the just processed day so that it won't run the next day.

TMstop=$TMg

cd /raid2/cliu/sstday/script/
 
done


# generate NOMADS NetCDF

rm /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_NOMADS.x
lf95 -o /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_NOMADS.x /raid2/cliu/sstday/ftn/oi_netcdf_navy_intv2_NOMADS.f -M$NFf90/src/f90 -L$NFf90/lib -lnetcdf 
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit

cat << netcdfEOF> netcdf.parm
$iyrs $imos $idas $iyre $imoe $idae
$curryear,$currmon,$today,$hour,$min
$buoy_cov,$ship_cov,$noaa19_day_cov,$noaa19_nte_cov,$metop_day_cov,$metop_nte_cov,$ice_cov
netcdfEOF
cat netcdf.parm

 /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_NOMADS.x -Wl,-T <netcdf.parm
echo 'oi_netcdf_navy_intv2_NOMADS.x : call exit ' $stopcode


if [ $stopcode -eq 10 ]
then

    echo 'oi_netcdf_navy_intv2_NOMADS.x' $stopcode

fi 

if [ $stopcode -eq 100 ]
then
     echo 'oi_netcdf_navy_intv2_NOMADS.x' $stopcode
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi_netcdf_navy_intv2_NOMADS.f data error'
  exit
fi 

echo "************** end time for run NOMADS NetCDF =" `date '+%T'`


# generate GHRSST NetCDF

rm /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_GHRSST.x
lf95 -o /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_GHRSST.x /raid2/cliu/sstday/ftn/oi_netcdf_navy_intv2_GHRSST.f -M$NFf90/src/f90 -L$NFf90/lib -lnetcdf
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit

rm /raid2/cliu/sstday/script/fr_navy_intv2.x
lf95 -o /raid2/cliu/sstday/script/fr_navy_intv2.x /raid2/cliu/sstday/ftn/fr_navy_intv2.f
     err=$?
     [ $err -ne 0 ] && echo RED-STOP: compile error exit     

cat << netcdfEOF> netcdf_ghrsst.parm
$iyrs $imos $idas $iyre $imoe $idae
$curryear $currmon $today
netcdfEOF
cat netcdf_ghrsst.parm

 /raid2/cliu/sstday/script/oi_netcdf_navy_intv2_GHRSST.x -Wl,-T <netcdf_ghrsst.parm
   stopcode=$?  
echo 'oi_netcdf_navy_intv2_GHRSST.x : call exit ' $stopcode

if [ $stopcode -eq 10 ]
then

    echo 'oi_netcdf_navy_intv2_GHRSST.x' $stopcode
fi 

if [ $stopcode -eq 100 ]
then
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: oi_netcdf_navy_intv2_GHRSST.f data error'
  exit
fi 

#Generate FR file
 /raid2/cliu/sstday/script/fr_navy_intv2.x -Wl,-T <netcdf_ghrsst.parm 
   stopcode=$?  
echo 'fr_navy_intv2.x : call exit ' $stopcode

if [ $stopcode -eq 10 ]
then

    echo 'fr_navy_intv2.x' $stopcode

fi 

if [ $stopcode -eq 100 ]
then
  exit
fi

if [ $stopcode -ne 1 -a $stopcode -ne 10 -a $stopcode -ne 100 ]
then
  echo 'RED-STOP: fr_navy_intv2.f data error'
  exit
fi 

echo "************** end time for run GHRSST NetCDF =" `date '+%T'`



# scp NetCDF to eclipse

TM=$iyrs$imos$idas
TMe=$iyre$imoe$idae

while [ "$TM" -le "$TMe" ]
do

#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc eclipse-d2:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR
mv /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc'
#cp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc'
scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc' eclipse-d:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR

CreateMNF /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc'
scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc.mnf' eclipse-d:/san/ftp/pub/oisst/NetCDF-uncompress/$iyrs/AVHRR

#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc eclipse-d:/raid/ftp/pub/OI-daily-v2/NetCDF-uncompress/$iyrs/AVHRR


# sftp to gulp2 Archive

rm ftp_archive

echo "open gulp2.ncdc.noaa.gov" >> ftp_archive
echo "user anonymous Chunying.Liu@noaa.gov" >> ftp_archive
echo "lcd /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2" >> ftp_archive
echo "cd /pub/upload/Ingest/OISST/avhrr_only/$iyrs " >> ftp_archive
echo  put avhrr-only-v2.$TM'_preliminary.nc' >> ftp_archive
echo  put avhrr-only-v2.$TM'_preliminary.nc.mnf' >> ftp_archive
echo "quit" < ftp_archive 

ftp -n -v -i < ftp_archive


if [ -f  /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc.gz ]
then 
rm /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc.gz
fi 

gzip /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc'
#gzip /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc
scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary.nc.gz' eclipse-d:/san/ftp/pub/oisst/NetCDF/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc.gz eclipse-d2:/san/ftp/pub/oisst/NetCDF/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/NOMADS/AVHRR_intv2/avhrr-only-v2.$TM.nc.gz eclipse-d:/raid/ftp/pub/OI-daily-v2/NetCDF/$iyrs/AVHRR

if [ -f  /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM.gz ]
then 
rm /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM.gz
fi 

#mv /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary'
cp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary'
gzip /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary'
scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM'_preliminary'.gz eclipse-d:/san/ftp/pub/oisst/IEEE/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM.gz eclipse-d2:/san/ftp/pub/oisst/IEEE/$iyrs/AVHRR
#scp /raid2/sstday/$iyrs/netcdf/IEEE/AVHRR_intv2/avhrr-only-v2.$TM.gz eclipse-d:/raid/ftp/pub/OI-daily-v2/IEEE/$iyrs/AVHRR
 
#scp GHRSST NetCDF

if [ -f  /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2 ]
then 
rm /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2
fi 

bzip2 /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc

cut -c '2-' /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml > junk9
mv junk9 /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml

md5sum /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml>/raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5

md5sum /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2>/raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2/$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5

# sftp to melia

 rm ftp_melia

# echo "user sftp-ghrsst cyclops-12" > ftp_melia
 echo "cd NCDC/tmp" >> ftp_melia
# echo "bin" >> ftp_melia
# echo "prompt" >> ftp_melia
 echo "lcd /raid2/sstday/$iyrs/netcdf/GHRSST/AVHRR_intv2" >> ftp_melia
 echo "put $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2" >> ftp_melia
 echo "put FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml" >> ftp_melia
 echo "put FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5" >> ftp_melia
 echo "put $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5" >> ftp_melia
 
 echo "rename $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2 ../$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2" >> ftp_melia
 echo "rename FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml ../FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml" >> ftp_melia
 echo "rename FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5 ../FR-$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.xml.md5" >> ftp_melia
 echo "rename $TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5 ../$TM-NCDC-L4LRblend-GLOB-v01-fv02_0-AVHRR_OI.nc.bz2.md5" >> ftp_melia
 

# echo "quit" >> ftp_melia

sftp sftp-ghrsst@melia.jpl.nasa.gov < ftp_melia 


#find the next day.
  
TM=`sh /home/cliu/shell_lib/finddate.sh $TM d+1`

iyrs=`expr $TM | cut -c1-4`

echo "************** end time for scp NetCDF to JPL =" `date '+%T'`
  
done 

echo 'NetCDF were generated and ftp to melia'



