c@***h*   OISST/ice2_1440x720.f
c NAME    
c   ice2_1440x720.f
c     
c LOCATION
c   rainband: /raid/cliu/oiweekly/ftn/ice2_1440x720.f  
c
c ABSTRACT
c      convert ice from 1/2 degree to 1/4 degree
c      ice is 1/2 degree, from N-S, 0.25-359.75                                              c
c      read 1/2 degree global ascii ice file from wgrib                                      c
c      wgrib /raid2/sstday/$iyrmid/obs/ice/ice.$iyrmid -d $ddd -text -o $ice_globe
c      wgrib /raid2/sstday/$iyrmid/obs/ice/ice.$iyrmid -V -d $ddd > wgrib_info
c      wgrib_info
c      latlon: lat  89.750000 to -89.750000 by 0.500000  nxny 259200
c            long 0.250000 to -0.500000 by 0.500000, (720 x 360) scan 0 mode 128 bdsgrid 1  c
c     ice:          N-S 89.75, 89.25,88.75,...-89.75                                        c
c                  E -W  0.25,0.5,0.75,...,359.75                                          	      
c                   Ice:0-1 fraction.
c     According to Grumbine's email on 2004/09/29                                           c
c                   land=1.57                                                               c
c                   bad data=1.66                                                           c
c                   weather=1.77                                                            c 
c                   coast=1.95                                                              c
c                   nodata=2.24 
c      I found values like this in 2005,2004 but not in 1995. 
c
c      iwget=0 if file_in from wgrib
c      iwget=1 if file_in from wget                                                         c		      
c                                                                                           c
c      read and convert them into 1/4 degree  
c
c AUTHOR
c  Chunying Liu
c
c CREATION DATE
c  DATE: 2005-12-25                       
c                                                                       
c COPYRIGHT
c  THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC DOMAIN AND
c  THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE.  THEY ARE FURNISHED "AS IS." THE 
c  AUTHORS, THE UNITED STATES GOVERNMENT, ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, 
c  AND AGENTS MAKE NO WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE 
c  SOFTWARE AND DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR
c  THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL SUPPORT 
c  TO USERS.
c
C PROGRAM HISTORY
c   2005-12-25   Chunying Liu                                                         
c                                                                                           c
c INPUTS 
c                 before or on 2004/8/26, use                                               c	       
c          mask ='/raid/cliu/oiweekly/data/sea_ice/ice_land.20010829.dat '                  c
c                 After Aug. 27, 2004 ,use                                                  c
c               = '/raid/cliu/oiweekly/data/sea_ice/ice_land.20040827.dat '                 c
c         land_mask     land=157                                                            c
c                       coast=195                                                           c
c                       sea=0  
c                    1/2 degree N-S 0.5-359.5     integer                                   c
c                                                                                           c
c     quarter_mask_in='/raid/rreynold/ftn/clm/land/quarter-mask'                            c
c     cmask       - land sea tag. 1/4 degree, 0-360E, 90S-90N.   land=0, sea=1.   integer   c
c                                                                                           c		       
c    file_in         - /raid2/sstday/$iyrmid/obs/ice/ice.YYYYMMDD                           c
c
c OUTPUTS 
c                                                                                           c
c   (pass from the shell script)                                                 
c   file_out_720x360   -/raid2/sstday/$iyrmid/grads/ice/icecon720x360.YYYYMMDD              c
c   file_out_1440x720 -/raid2/sstday/$iyrmid/grads/ice/icecon.YYYYMMDD                      c
c                                                                                           c
c ATTRIBUTES
c   LANGUAGE: Fortran 90 
c   MACHINE: Red hat Linux rainband
c                                                                                          						   
c@*****                                                                           
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

        parameter (imx=720,imy=360,imxp1=imx+1,imyp1=imy+1,
     1   imxp2=imx+2,imyp2=imy+2,jmx=1440,jmy=720)
     
	real ice(imx,imy), ice4(jmx,jmy),tmp(imxp2,imyp2)
	integer ice_mask(imx,imy),ice_mask_tmp(imxp2,imyp2)
	dimension wk(imx,imy),lwk(imx,imy)
        character*20 head1,head2,word	
c	real lat(imy),lon(imx)
	dimension alon(jmx),alat(jmy)
        dimension xt(imxp2),yt(imyp2)
	integer iwget,dice,cmask(jmx,jmy),land_mask(imx,imy)
	
	character*80 file_in, file_out_720x360, file_out_1440x720
	character*80  quarter_mask_in
	
	call timer (itime1)
	
        read 666, quarter_mask_in,file_in,file_out_720x360,
     1            file_out_1440x720
        read *,   iyrmid, immid, idmid 
        read *,   iwget
666     format(a80)  
        
c        print*, '1/2 degree land mask file:       ', mask
	print*, '1/4 degree Land mask file:       ', quarter_mask_in
        print*, 'Input 1/2 degree ascii file:     ', file_in
        print*, 'Output 1/2 degree grid file:     ', file_out_720x360
        print*, 'Output 1/4 degree grid file:     ', file_out_1440x720
	print*, 'Day of process:                  ', iyrmid, immid, idmid
	print*, 'Ice format (wget format=1, wgrib format=0):',iwget
                 
	undef=-1.0E30
    
c	open(unit=11,file='/raid/cliu/oiweekly/2005/obs/ice/'//
c     1                   'ice.globe.20050616',status='old')
        open(unit=11,file=file_in,status='old')
	
	read(11,*) head1,head2
	print*,head1,head2
	
	if(iwget .eq. 1 )then
c        read ice from nomads, ice from south to north	
	do 10 j=1,imy
	read(11,*)word,(ice(i,j),i=1,imx)
c	print*,word,(ice(i,j),i=1,imx)
10      continue
        else
	
c       read ice from ftp wgrib. Ice is from north to south
c       read it to S to N to matach the ice land mask file 
	
	read(11,*)ice(:,imy:1:-1)
        endif
	
c        print*,'ice(240,156)= ',ice(480:484,312:316)
c      	print 123,ice
123     format(10f7.2)	


        call maxmin(ice,imx,imy,undef,'ice     ')
	

!       get rid of the land value 
!       read the land mask first

c        mask='/raid/cliu/oiweekly/data/sea_ice/ice_land.20010829.dat'
c        open(31, file=mask, form='unformatted')
c        read(31)land_mask
c	print 101, land_mask
c101     format(20i4)	
	
!        read((land_mask(i,j),i=1,imx),j=1,imy)  
!        print 108,land_mask(361:362,1:52)
!        print*,land_mask
!108     format(1x,12i6)		
c	call imaxmin(land_mask,imx,imy,undef,'landmask')

c        WHERE(land_mask(:,:)==0)ice(:,:)=undef	        
c        WHERE(land_mask(:,:)==157)ice(:,:)=undef
c	WHERE(land_mask(:,:)==195)ice(:,:)=undef
	
c   change land mask value to land=0, coast=0 & ocean = 1.      
	
c	WHERE(land_mask(:,:)==0)land_mask(:,:)=1
c	WHERE(land_mask(:,:)==195)land_mask(:,:)=0
c	WHERE(land_mask(:,:)==157)land_mask(:,:)=0

c   generate ice mask for interpolation
c        ice_mask=1
c       if land, ice mask=0	
c	WHERE(land_mask(:,:)==0)ice_mask(:,:)=0
c       if open water, ice mask=0	
c        WHERE(ice(:,:)==0)ice_mask(:,:)=0
c        call imaxmin(ice_mask,imx,imy,undef,'ice_mask')
	
	ice_mask=0
	do j=1,imy
	do i=1,imx
	if(ice(i,j).gt.0 .and. ice(i,j).le.1)then	
	ice_mask(i,j)=1	
	endif
        enddo
        enddo
	
	
c	open(unit=61,file='/raid2/sstday/1995/obs/ice/ice_mask.grd',
c     1 	status='unknown',form='unformatted')             
c      	write(61) ((1.0*ice_mask(i,j),i=1,imx),j=1,imy)
	
!        WHERE(ice(:,:)==1.57)ice(:,:)=undef	

c        call maxmin(land_mask,imx,imy,undef,'mask_0_1')
	
		
!       get rid of all the bad values that are greater than 1 or less than 0.
        n1=0	
	do j=1,imy
	do i=1,imx
	if(ice(i,j).gt.1 .or. ice(i,j).le.0 .and. ice(i,j).ne.undef)then
c	print*,'ice=',ice(i,j)
	ice(i,j)=undef
	n1=n1+1
	endif
        enddo
        enddo
	print*,'ice concentration>1 or <0 ',n1
	
c	n=0
c	do j=1,imy
c	do i=1,imx	
c	if(ice(i,j).eq.undef .and. land_mask(i,j) .eq. 1 )then
c	n=n+1
c	ice(i,j)=undef
c        land_mask(i,j)=0  
c	endif
c        enddo
c        enddo
c	print*,'if it is ocean and ice has missing value=',n
	
c	print*,'ice(240,156)_half= ',ice(480:481,312:313)
c	print*,'ice(325,157)_half= ',ice(649:651,312:314)
c       print*,'ice(150,166)_half= ',ice(299:300,331:332)
c	print*,'ice(247,158)_half= ',ice(493:494,315:316)        
	
	call maxmin(ice,imx,imy,undef,'ice.1deg')
	
c       write out the 1 degree ice in grid format

        open(unit=51,file=file_out_720x360,status='unknown',
     1  form='unformatted')             
      	write(51) iyrmid,immid,idmid,((ice(i,j),i=1,imx),j=1,imy)       

c  convert to 1/4 degree using intrp.f
      
c  first expand the rows to north and south, columns to east and west	

       do i=1,imx
	  ip = i + 1
          do j=1,imy
	    jp = j + 1
            tmp(ip,jp) = ice(i,j) 
	    ice_mask_tmp(ip,jp) = ice_mask(i,j)
          enddo
       enddo

c  expanding column
          
       do j=2,imyp1
	  tmp(imxp2,j) = tmp(2,j)
	  tmp(1,j) = tmp(imxp1,j)
	  
	  ice_mask_tmp(imxp2,j) = ice_mask_tmp(2,j)
	  ice_mask_tmp(1,j) = ice_mask_tmp(imxp1,j)
	  
       enddo
       
c  expanding rows
       
       do i=1,imxp2
	  tmp(i,1) = tmp(i,2)
	  tmp(i,imyp2) = tmp(i,imyp1)
	  
	  ice_mask_tmp(i,1) = ice_mask_tmp(i,2)
	  ice_mask_tmp(i,imyp2) = ice_mask_tmp(i,imyp1)
       enddo 

c     calculated the 1/4 degree and 1 degree grid lon, lat

      ay1 = -89.875
      ax1 = 0.125
      dall = ax1*2

      do i=1,jmx
        alon(i) = dall*float(i-1) + ax1
      enddo
      call maxmin (alon,jmx,1,undef,'alon    ')
      
      do j=1,jmy
        alat(j) = dall*float(j-1) + ay1
      enddo
      
      call maxmin (alat,jmy,1,undef,'alat    ')
c      print 888,alon
c      print 888,alat(jmy:1:-1)
c888   format(f8.3)
      
      xt1 = -0.25
      yt1 = -90.25
      dxy = 0.5
      
      do i=1,imxp2
        xt(i) = dxy*float(i-1) + xt1
      enddo
      call maxmin (xt,imxp2,1,undef,'xt0.5deg')
      
      do j=1,imyp2
        yt(j) = dxy*float(j-1) + yt1
      enddo
      call maxmin (yt,imyp2,1,undef,'yt0.5deg')
      print *,' '

c     do the interpolate

c      print*,'ice before intrp=',ice(540,300)

      call intrp(tmp,imxp2,imxp2,imyp2,ice4,jmx,jmx,jmy,
     1   xt,yt,alon,alat,ice_mask_tmp,2,undef)        
     
c      print*,'ice after intrp=',ice4(1079:1082,599:602)
      
c      print*,'ice after intrp 240x156=',ice4(960:961,624:625)
c      print*,'ice after intrp 325x157=',ice4(1297:1300,625:628)
c      print*,'ice after intrp 325x157=',ice4(1300,625)
      
      print*,'ice after intrp 150,166='
      print 333, ice4(594:603,658:667)
333   format(10f5.1)

      
      print*,'ice after intrp 150,166=',ice4(600,663)
      
      print*,'ice after intrp 247,158=',ice4(985:988,629:632)
      print*,'ice after intrp 247,158=',ice4(988,631)
              
      call maxmin(ice4,jmx,jmy,undef,'ice4    ')
      
c  appy 1/4 degree land mask

c     read quater degree mask

c      quarter_mask_in='/raid/rreynold/ftn/clm/land/quarter-mask'
      open (30,file=quarter_mask_in,form='unformatted')
      read (30) cmask
      call maxmin (cmask,1440,720,undef,'land sea  ')
      call maxmin (cmask,1440,720,1.,'land pts  ')
      call maxmin (cmask,1440,720,0.,'ocean pts ')

       do i=1,jmx
	  do j=1,jmy
	    if (cmask(i,j).lt.0.1 .or. ice4(i,j).lt.0) then
c	    if (cmask(i,j).lt.0.1) then
	      ice4(i,j) = undef
	      
	    endif
	  enddo
       enddo
             
       print *,' 1/4 degree land sea mask applied'
       call maxmin (ice4,jmx,jmy,undef,'ice4mask')         	
	
c       print 111,ice
111    format(12f12.1)    	
	
c        open(unit=52,file='/raid/cliu/oidaily/2005/'//
c     1  'ice1440x720_20050616',status='unknown',form='unformatted')   
     
       print*,'ice after intrp mask 150,166='
       print 333, ice4(594:603,658:667)
       
       open(unit=52,file=file_out_1440x720,status='unknown',
     1      form='unformatted')                    
	write(52) iyrmid,immid,idmid,((ice4(i,j),i=1,jmx),j=1,jmy)
!        print 108,ice4(350:352,1:52)
!108     format(1x,12f6.2)	
	
!	print*,ice(181,26)	
!	print*,ice4(720:727,100:107)
	call timer (itime2)
        tsec = float(itime2-itime1)*.01
        print *,tsec,' seconds for complete ice2_1440x720.f code'
	print*,'GREEN-SUCCESSFUL! ice2_1440x720 MAIN'
	call exit(1)
	end
	
				
	subroutine maxmin (fld,im,jm,undef,name)
c
c   compute maximum, minium and average of fld and print
c
      dimension fld(im,jm)
      character*8 name
      fldmin = 1.e30
      fldmax = -fldmin
      inum = 0
      ave = 0.
      do 90 i=1,im
      do 90 j=1,jm
      if (fld(i,j).ne.undef) then
        inum = inum + 1
        ave = ave + fld(i,j)
        if (fldmin.gt.fld(i,j))  fldmin = fld(i,j)
        if (fldmax.lt.fld(i,j))  fldmax = fld(i,j) 
      endif
   90 continue
      if (inum.gt.0) then
        r = 1./float(inum)
        ave = ave*r
      else
        fldmin = 0.
        fldmax = 0.
      endif
      print 88,ave,fldmin,fldmax,inum,name
   88 format (' ave =',f10.3,2x,'min =',f10.3,2x,
     1 'max =',f10.3,2x,'inum =',i8,2x,a8)
c      print*,' ave =',ave
c      print*,'fldmin=',fldmin
      return 
      end


      subroutine imaxmin (fld,im,jm,undef,name)
c
c   compute maximum, minium and average of fld and print
c
      integer fld(im,jm)
      integer fldmin,fldmax
      character*8 name
      fldmin = 1e30
      fldmax = -fldmin
      inum = 0
      ave = 0.
      do 90 i=1,im
      do 90 j=1,jm
      if (fld(i,j).ne.undef) then
        inum = inum + 1
        ave = ave + fld(i,j)
        if (fldmin.gt.fld(i,j))  fldmin = fld(i,j)
        if (fldmax.lt.fld(i,j))  fldmax = fld(i,j) 
      endif
   90 continue
      if (inum.gt.0) then
        r = 1./float(inum)
        ave = ave*r
      else
        fldmin = 0
        fldmax = 0
      endif
      print 88,ave,fldmin,fldmax,inum,name
   88 format (' ave =',f10.3,2x,'min =',i10,2x,
     1 'max =',i10,2x,'inum =',i8,2x,a8)
      return 
      end
      
      
      subroutine intrp (cn,imc,ic,jc,fn,imf,if,jf,cx,cy,fx,fy,ls,
     1 intmin,undef)          
      dimension cn(imc,jc),cx(ic),cy(jc),fn(imf,jf),fx(if),fy(jf)       
      dimension ls(imc,jc)
c     intrp interpolates data from grid cn to grid fn where the         
c     gridspace cn completely overlies the gridspace fn.                
c     imc= 1st dimension of cn in calling routine                       
c     ic= ending i index on cn                                          
c     jc= ending j index on cn                                          
c     imf= 1st dimension of fn in calling routine                       
c     if= ending i index on fn                                          
c     jf= ending j index on fn                                          
c     cx= distribution of grid points in i direction on cn              
c     cy= distribution of grid points in j direction on cn              
c     fx= distribution of grid points in i direction on fn              
c     fy= distribution of grid points in j direction on fn              
c     the distributions cx and fx (cy and fy) are arbitrary except that 
c     they must be monotonic increasing and consistent with each other. 
c     i.e. if cx(i)=i say, then fx(i) will take on values consistent    
c     with this distribution and determined by the placement of the     
c     points of fn with respect to that of the points of cn.            
c     note that cx(1) should be less than or equal to fx(1)             
c               cy(1) should be less than or equal to fy(1)             
c               cx(ic) should be greater than or equal to fx(ic)        
c               cy(ic) should be greater than or equal to fy(ic)        
c     courtesy of gfdl/noaa ron pacanowski                              
c
c     modified so missing data OK
c     intmin is number of missing points allowed: range 1-4
c     ls is array the same size as cn: values are 0 for missing or 1 for OK
c     fn(i,j) = undef if no interpolation is possible
c     undef is value set by user to indicate interpolated grid is undefined    
c
c      print*,'-------start intrpolation---------'

      if(cx(1).le.fx(1).and.cx(ic).ge.fx(if).and.cy(1).le.fy(1).and.    
     1 cy(jc).ge.fy(jf)) go to 10                                       
      write(6,9999)                                                     
      go to 20                                                          
  10  do 12 i=2,ic                                                      
      if(cx(i).ge.cx(i-1)) go to 12                                     
      write (6,9998)                                                    
      go to 20                                                          
  12  continue                                                          
      do 14 j=2,jc                                                      
      if(cy(j).ge.cy(j-1)) go to 14                                     
      write (6,9998)                                                    
      go to 20                                                          
  14  continue                                                          
      do 16 i=2,if                                                      
      if(fx(i).ge.fx(i-1)) go to 16                                     
      write (6,9998)                                                    
      go to 20                                                          
   16 continue                                                          
      do 18 j=2,jf                                                      
      if(fy(j).ge.fy(j-1)) go to 18                                     
      write(6,9998)                                                     
      go to 20                                                          
   18 continue                                                          
      go to 30                                                          
  20  write (6,9994)                                                    
      write (6,9993) (cx(i),i=1,ic)                                     
      write (6,9993) (cy(j),j=1,jc)                                     
      write (6,9993) (fx(i),i=1,if)                                     
      write (6,9993) (fy(j),j=1,jf)
      
      print*,'RED-STOP! SUBROUTINE-intrp!'                                     
      call exit(100) 
                                                                   
   30 continue                                                          
      do 100 j=1,jf                                                     
      do 110 l=1,jc                                                     
      if(cy(l).lt.fy(j)) go to 110                                      
      jn=l-1                                                            
      js=l                                                              
      if(jn.eq.0) js=2                                                  
      if(jn.eq.0) jn=1                                                  
      go to 111                                                         
  110 continue                                                          
  111 continue                                                          
      do 100 i=1,if                                                     
      do 120 l=1,ic                                                     
      if(cx(l).lt.fx(i)) go to 120                                      
      ie=l                                                              
      iw=l-1                                                            
      if(iw.eq.0) ie=2                                                  
      if(iw.eq.0) iw=1                                                  
      go to 121                                                         
  120 continue                                                          
  121 continue                                                          
      lsum = ls(ie,js) + ls(iw,js) + ls(ie,jn) + ls(iw,jn)
c      print*,'lsum=',lsum
      
      if (lsum.ge.intmin) then                                                          
        a = fx(i) - cx(iw)                                                    
        b = cx(ie) - fx(i)                                                    
        c = fy(j) - cy(jn)                                                    
        d = cy(js) - fy(j) 
c	print*,'abcd=',a,b,c,d
	                                                   
        ac = a*c * float( ls(ie,js) )                                     
        bc = b*c * float( ls(iw,js) )                                     
        ad = a*d * float( ls(ie,jn) )                                     
        bd = b*d * float( ls(iw,jn) )
c	print*,'ac,bc,ad,bd=',ac,bc,ad,bd
	                                     
        top = ac*cn(ie,js) + bc*cn(iw,js) + ad*cn(ie,jn) + bd*cn(iw,jn)   
        bot = ac + bc + ad + bd 
c	print*, cn(ie,js),cn(iw,js),cn(ie,jn),cn(iw,jn)
c	print*,'top=',top
c	print*,'bot=',bot
	                                         
        fn(i,j) = top/bot                                                      
      else
        fn(i,j) = undef
      endif
  100 continue
      return                                                            
 9999 format(1x,'grid interpolated to exceeds grid int from')           
 9998 format(1x,'cx,cy,fx, or fy not monotonic')                        
 9994 format(1x,'cx,cy,fx,fy follow')                                   
 9993 format(1x,10e13.6)                                                
      end                                                               
