ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     main program buoy_ship_daily_historic_firstguessclim_col.f
c     use first guess as climatology instead of interpolat OI weekly sst
c
c     main program documentation block                                       
c                .      .    .                                       .                                                                         
c abstract: Quality control sst ship and buoy data.
c   reads the surface marine ship and buoy data from            
c   NCEP weekly file.  extracts ship and buoy    
c   data of sea surface temperature (sst), position, date and time of   
c   the observation and ship or buoy id.  these data                    
c   are separated into  ship and buoy categories and sorted by id.      
c   the data are quality controlled by ship and buoy tracking           
c   algorithms and by comparing the sea surface temperatures            
c   against climatology(monthly mean and monthly standard deviation).  
c   the quality controlled data are the output.   
c   
c   The main code reads the buoy ship observations, land mask, 
c   and climatology data. Then it does a preliminary quality contol
c   (such as on land, lat lon are within the globe, sst not mssing, ID ok ...). 
c   Then the buoy ship obs are put to name_ship array and name_buoy
c   array seperately for the future QC.                        
c                                                                       
c program history log:                                                  
c   1990-12-28  richard w. reynolds                                     
c   1992-04-30  richard w. reynolds  - correct small error in ship      
c                                    tracking program.                  
c   1994-07-25  diane c. stokes    - modified open statement and      
c                                  array sizes for direct access      
c                                  reads due to change in size and    
c                                  attributes of insitu archive       
c   1996-08-07  diane c. stokes    - modifications to run on cray.
c                                  new daily input files extracted
c                                  from bufr data. also change to
c                                  1-degree Adjusted OI climatology
c   1998-04-20  diane c. stokes  - 4-digit years.  y2k compliant
c   2000-02-01  Diane C. Stokes  - move to IBM SP
c                                - changed gross check of max sst to 40
c                                - keep hour in hundredths (was tenths
c                                  for i*2 on ibm.  new buoys reporting
c                                  more than once per hour now.  more
c                                  accurate time helps speed check)
c   2000-03-18  Diane C. Stokes  - fixed dh in stats for hr in 100ths.
c                                  For weeklyoi, added extra output files
c                                  read of insituarc, land check (lc was
c                                  done in shiparc and buoyarc for daily)  
c   2005-01-20    Chunying Liu   - read weekly buoy ship obs from ftp
c                                 change the way of passing files
c                                 read the land mask and do the land sea check.
c                                 
c                                 Add duplicated check and get rid off 
c                                 the duplicated record in the shipdt.f
c                                 and buoydt.f before they call any subroutine
c   2007-06-08    Chunying Liu   - add the color monitor part.
c
c main program: buoy_ship_daily_historic_col.f
c
c input file:    sea mask
c     sea_mask_in    - /raid/cliu/oiweekly/data/lstags.onedeg.dat
c         
c                sst climatology(12 months; 1 deg grid; 90s-90n) :
c     file_clim_in   -  /raid/cliu/oiweekly/data/aoi.61.90.clim
c
c               sst st. dev sst climatology (12 months; 2 deg grid; - 80s-80n) 
c     file_stdev_in  - /raid/cliu/oiweekly/data/stdev2d
c               
c             weekly in situ buoy ship sst from ftp 
c             /raid/cliu/oiweekly/YYYY/obs/buoyship/NCEP/buoyshipYYYYMMDD.txt
c
c    
c                                                                       
c output files:  (pass from the shell script)                            
c     file_buoy_out  - quality control buoy data.
c                    /raid/cliu/oiweekly/$iyrmid/obs/NCEP/shipYYYYMMDD.dat
c
c     file_ship_out  - quality control ship data.
c                    /raid/cliu/oiweekly/$iyrmid/obs/NCEP/buoyYYYYMMDD.dat
c
c     file_clim_out  - sst climatology (mean and standard deviation        
c                      for the data period of the analysis).
c                    /raid/cliu/oiweekly/data/clim/climYYYYMMDD.dat 
c
c     buoyship_file_out - weekly buoy ship observation data from ftp NCEP.
c                        /raid/cliu/oiweekly/YYYY/obs/buoyship/NCEP/NCEPYYYMMDD.txt  
c                   
c                                                                       
c   subprograms called:                                                 
c     unique:  - buoydt, shipdt, dayclm1d, dayclm, intrp,  longfx,
c                stat,   spdfix                   
c     library:                                                          
c       w3lib  -  iw3jdn, qsort
c                                                                       
c   exit states:                                                        
c     cond =   3 - buoy: not all days of data are available in archive 
c              4 - ship: not all dates available in archive
c              5 - that week not available in archive      
c             13 - premature end of file for climatology 
c             14 - premature end of file for stdev               
c             15 - interpolation error in dayclm1d                        
c             16 - interpolation error dayclm    
c             17 - interpolation error intrp
c                                                                       
c remarks:  subroutine buoydt processes the buoy data                   
c           subroutine shipdt processes the ship data                   
c            additional important variables follow:                     
c               iyrend: end year (4 digits) of analysis                 
c               imend : end month of analysis                           
c               idend : end day of analysis                             
c                                                                       
c important variables:   
c     iyrst,imonst,idast - starting day of data to be extracted.                  
c                        - the day is yyyy,mm,dd     pass from the shell script.
c     iyrst,imonst,idast - ending day of data to be extracted.                  
c                        - the day is yyyy,mm,dd     pass from the shell script.
c     iyrmid,imonmid,idamid - mid day of the week to be extracted.                  
c                           - the day is yyyy,mm,dd  pass from the shell script.                                      
c     maxdr     -  the maximum number of observations which can be used  
c               -  by the subroutine; presently 2,000,000
c     name_ship -  ship observations
c               -  character*26 array 
c               -  the first six characters are the id                               
c               -  the next two characters are the relative day for the     
c               -  period, the next four characters are the hour times 100.
c               -  character 13:26 are latitude, logitude, and sst.                       
c     idim_ship -  total ship obs 
c     name_buoy -  buoy observations 
c               -  the first six characters are the id,                  
c               -  the next two characters are the relative day for the     
c               -  period, the next four characters are the hour times 100.
c               -  character 13:26 are latitude, logitude, and sst.                         
c     idim_buoy -  total buoy obs  
c
c     clima1    - the 1 degree resolution mean sst climatology for       
c               - the center of the period of interest.                  
c     clims1    - the 1 degree resolution standard deviation of the      
c               - sst, for center of the period of interest,             
c               - times smult.                                           
c               - (presently smult=3.5 in the main program )             
c               - the grid for both clima1 and clims1 is centered on     
c               - the half degree.  the first index is longitude         
c               - from 0.5e to 359.5e (range 1 to 360).  the second      
c               - index is latitude from -89.5 (89.5s) to 89.5 (89.5n)   
c               - (range 1 to 180).                                                                                                                                                           
c   sea_mask    - land sea tag. 1 degree, 0-360E, 90S-90N.   land=0, sea=1.                                       
c   cmask       - land sea tag. 1/4 degree, 0-360E, 90S-90N.   land=0, sea=1.      
c                                                                    
c   language: fortran 90 
c   machine:  Red hat Linux
c                                                                                                                                             
c.......................................................................
c   format of data in situ files  (3i2,i4,2i5,2i1,a6,18x,i3)                      
c                                                                       
c..   col     frmt   variable                                           
c..from  to                                                             
c..   1    2    i2    year
c..   3    4    i2    month
c     5    6    i2    day  
c     7   10    i4    hour (hundredths)                                 
c..  11   15    i5    latitude (hundredths degree) -- lt zero = south hemi   
c..  16   20    i5    longitude (hundredths degree) -- 0 to 36000 west 
c    21   21    i1    BUFR file type -- 1=ship 2=drifting buoy 3=moored buoy 
c    22   22    i1    Wind speed indicator   
c..  23   28    a6    station ident and/or buoy call sign                
c..  47   49    i3    sea surface temp (tenth deg c)    misg=999         
c.......................................................................                                                                  

      parameter (imx=1440,imy=720)
      character*80 file_in,sea_mask_in,quarter_mask_in
      character*80 ship_grid_out,buoy_grid_out
      character*80 ship_sobs_out,buoy_sobs_out
      character*80 ship_obs_out,buoy_obs_out
      character*80 file_clim_in,file_stdev_in
      character*80 navyeotfg
      integer iyrst,imonst,idast,iyrend,imoend,idaend,iyrmid,immid,idmid
      
      integer year, mon,day, IDID,year1
      integer  ihour, ilat, ilon, isst
      real    hour, alat, alon,asst
      character*6 cid
      integer sea_ict
      real cov_buoy,cov_ship,cov_buoyship
      parameter(maxdr=100000)                                             
      character*24 id                                                   
      character*24 name_buoy(maxdr),name_ship(maxdr)                                                 
      integer ihr,lon,lat                       
      integer iw3jdn
      dimension sea_mask(360,180),lsea_mask(360,180)
      dimension cmask (1440,720)
      dimension stdev12(12,360,180),dstdev(362,180),wk(360,180),
     1          lwk(360,180)
      dimension yt(180),xt(362)
      dimension gsst(imx,imy),sst(360,180)
      dimension blat(720),blon(1440)
      logical lexist
      
      call timer (itime1)
 
      read 666, quarter_mask_in,file_stdev_in,file_in,
     1          navyeotfg,ship_obs_out,buoy_obs_out,
     2          ship_grid_out,buoy_grid_out,ship_sobs_out,buoy_sobs_out
      
      read *, iyrmid,immid,idmid
      read *, cov_buoy
      read *, cov_ship
      read *, cov_buoyship

666   format(a80)
            
cliu      print*, 'sea  mask file:           ', sea_mask_in
      print*, 'quarter mask file:        ', quarter_mask_in
      print*, 'Monthly stdev file:       ', file_stdev_in
      print*, 'Input buoy ship file:     ', file_in
      print*, 'navy eot firstguess:      ', navyeotfg 
      print*, 'Ship obs out file:        ', ship_obs_out
      print*, 'Buoy obs out file:        ', buoy_obs_out     
      print*, 'Ship grid out file:       ', ship_grid_out
      print*, 'Buoy grid out file:       ', buoy_grid_out
      print*, 'Ship sobs out file:       ', ship_sobs_out
      print*, 'Buoy sobs out file:       ', buoy_sobs_out
      print*, 'Mid day of the week:      ', iyrmid, immid, idmid
      print*, 'Buoyship coverage:      ', cov_buoy,cov_ship,cov_buoyship
      
c   open daily obs files
      open(51,file=buoy_obs_out,form='formatted')
      open(52,file=ship_obs_out,form='formatted')
      
c   open daily SST grid file      
      open(61,file=buoy_grid_out,form='unformatted')
      open(62,file=ship_grid_out,form='unformatted')

c   open daily super obs file      
      open(71,file=buoy_sobs_out,form='unformatted')       
      open(72,file=ship_sobs_out,form='unformatted')  
      
c output GIS files
      open(44,file='/raid/cliu/oidaily/2006/obs/point/ship/'//
     1             'ship_NCEP.txt',form='formatted')
      write(44,*)'lon,lat,sst,ship_id'
      
      open(22,file='/raid/cliu/oidaily/2006/obs/point/buoy/'//
     1             'moored_NCEP.txt',form='formatted') 
      write(22,*)'lon,lat,sst,moored_id'
      
      open(33,file='/raid/cliu/oidaily/2006/obs/point/buoy/'//
     1             'drift_NCEP.txt',form='formatted') 
      write(33,*)'lon,lat,sst,drift_id'       
            
c    read in standard deviation climatology                             
c                                                                       
      smult = 3.5
c                                                                       
c    sst values are eliminated when the absolute value of the anomaly   
c    is greater than smult*the standard deviation of the climatology    
c    the minimum value of the standard deviation is 1.0 degrees c.      
c    the maximum value of the standard deviation is 4.5 degrees c.                                                                            

c    read in oi.v2 mask

cliu      open (3,file=sea_mask_in,form='unformatted',
cliu     1        access='direct',recl=4*360*180)

      undef = -9999.
cliu      read (3,rec=1) sea_mask
cliu      print *,'got land/sea mask: v2'
cliu      call maxmin (sea_mask,360,180,undef,'sea_mask') 
cliu      call maxmin (sea_mask,360,180,0.,'sea_mask')

cliu      do 420 i=1,360
cliu      do 420 j=1,180
cliu      lsea_mask(i,j)=nint(sea_mask(i,j))
cliu420   continue  


c     read quater degree mask

      open (30,file=quarter_mask_in,form='unformatted')
      read (30) cmask
      call maxmin (cmask,1440,720,undef,'land sea  ')
      call maxmin (cmask,1440,720,1.,'land pts  ')
      call maxmin (cmask,1440,720,0.,'ocean pts ')

c     count how may sea pixels to calculate buoy ship data coverage.      
      sea_ict=0
      do i=1,imx
      do j=1,imy
      if(cmask(i,j).eq.1.0)then
      sea_ict=sea_ict+cmask(i,j)
      endif
      enddo
      enddo
      
      print*,'sea_ict=',sea_ict
       
c
c     read in coads standard deviation for 1950-79
c
      open (4,file=file_stdev_in,form='unformatted')
      dfoi = -1.8
      print *,'smult =',smult
      do imo=1,12
        read (4,end=5500) iyr,jmon,sst
        print *,'base period =',iyr,'   month =',jmon
        call maxmin (sst,360,180,undef,'sd-orig ')

        do j=1,180
          do i=1,360
	    ss = sst(i,j)
	    if (ss.lt.1.0) ss = 1.0                                           
            if (ss.gt.4.5) ss = 4.5 
	    stmp = ss*smult                                          
            stdev12(imo,i,j) = stmp
	    wk(i,j) = stmp
          enddo
        enddo
	
c        sd-fill = dtsd*smult	
c        call maxmin (sst,360,180,undef,'sd-fill  ')
        if (imo.eq.1) call maxmin (wk ,360,180,undef,'sd-scale ')
        enddo
      
c     now interpolate stdev to the correct day

c     Feb. 29 is set to 28 in dayclm
      jmmid = immid
      jdmid = idmid
      call dayclm (stdev12,jmmid,jdmid,dstdev,ierr)
      
      call maxmin (dstdev,362,180,undef,'intr std')
      if (ierr.ne.0)goto 1500
      
c  read in the first guess
     
       ijdmid = iw3jdn(iyrmid, immid, idmid)
       print 202,ijdmid,iyrmid, immid, idmid
     
202   format('Julian day=',i10,3x,'yr =',i5,3x,'mon =',i3,3x,'day =',i3)

      open(31,file=navyeotfg,form='unformatted',status='old',ERR=1235)

      ndays=1
      CALL GETFG (31,imx,imy,IERR,ijdmid,ndays,gsst,undef)
      call maxmin (gsst,imx,imy,undef,'gsst    ')
      
      If(IERR .EQ.1)THEN 
      print*,'RED-STOP! SUBROUTINE-getfg' 
      CALL EXIT (100)
      ENDIF           
            
c----------------------------------------------------------------------      
c     calculated the 1/4 degree and 1 degree grid lon, lat

c      undef = -9999.

      dall = 0.25
      dall2 = 0.125

      ay1 = -89.875
      ax1 = 0.125
      
      do i=1,1440
        blon(i) = dall*float(i-1) + ax1
      enddo      
      call maxmin (blon,1440,1,undef,'blon  ')
      
      
      do j=1,720
       blat(j) = dall*float(j-1) + ay1
      enddo
c      print*,'aalat(91)=',aalat(91)
      call maxmin (blat,720,1,undef,'blat  ')
      
      xt1 = -0.5
      yt1 = -89.5
c      yt1=0.5
      
      dxy = 1.
      do i=1,362
        xt(i) = dxy*float(i-1) + xt1
      enddo
      call maxmin (xt,362,1,undef,'xt:1-deg')
      do j=1,180
        yt(j) = dxy*float(j-1) + yt1
      enddo
      call maxmin (yt,180,1,undef,'yt:1-deg')      
       
c-------------------------------------------------------------------       
                      
c     read in the buoy ship file
      open(21,file=file_in, form='formatted',status='old',ERR=1234)
      
      nbuoy=0
      nship=0
      ndr_ship = 0   
      ndr_buoy = 0                                                                                                                                                                                                                                                                               
      nerr=0
      
      nnn=0 
      nland=0
      i_badclim=0
      i_globe=0
      i_badhour=0
      idbad_buoy = 0
      idbad_ship = 0
      i_badsst=0
      i_sst999=0
      i_idid=0
      
      inoid_ship=0
      inoid_buoy=0
      iship=0
      irigg=0
      ibuoy=0
      iplat=0
      ibbxx=0
c      
c     read in buoy ship observations and put them into 
c     buoy ship array seperately
c
                 	           
800   read(21,101, err=820,END = 8000) year1,mon,day,ihour,
     1     ilat,ilon,IDID,iwind,cid,isst
cliu   using monthly sst from ftp NCEP. For historic run     
101   format(3i2,i4,2i5,2i1,a6,18x,i3) 
      
      
c     convert year from 2 digital to 4 digital
      year=year1+2000 
      if(year1.ge.91)then
      year=year1+1900
      endif 
                
      
       ijd = iw3jdn(year,mon,day)
!      print*,ijd,year,mon,day

        if(ijd.ne.ijdmid)go to 800
        nnn=nnn+1 
	
	
	if(cid .eq. '3ECG9')then 
        print*, cid,'ihour=',ihour,'lat=',ilat,'lon=',ilon,'sst=',isst	
        endif  
	
	if(cid .eq. '1001')then 
        print*, cid,'ihour=',ihour,'lat=',ilat,'lon=',ilon,'sst=',isst	
        endif 
	
c  count idid>=4 or IDID =0

       if(IDID.ge.4 .or .IDID .eq.0)then
         i_idid=i_idid+1
         go to 800
       endif     
	
c       if(cid .eq. '32011')then 
c       print*, cid,'lat=',ilat,'lon=',ilon,'sst=',isst,'ihour=',ihour
c       endif    

c************************************************************************ 
c  do the 1/4 degree land mask check and 
c  using the new standard deviation and OISST to do the climatology check

c      make sure lat lon not out of the globe
      
       if (iabs(ilat).gt.8950.or.abs(ilon).gt.36000)then
       i_globe=i_globe +1
       go to 800
       endif

c       calculate the col & row number of each obs

c      convert alon from 0~360w to 0~360E) 

         ilon=36000-ilon    

        alat=0.01*ilat
	alon=0.01*ilon
	asst=0.1*isst	           	
	
	ii = 1 + nint(4.*(alon-ax1))
	if (ii.eq.0) ii = 1
        if (ii.eq.1441) ii = 1440
	dlon = alon-blon(ii)
		
	if (abs(dlon).gt.dall2) then
	    print *,'warning'
            print 109,ii,alon,blon(ii),dlon
        endif
109     format ('lon: ',i5,3f10.3)	
	
        jj = 1 + nint(4.*(alat-ay1))
        if (jj.eq.0) jj = 1
        if (jj.gt.720) jj = 720
	dlat = alat-blat(jj)
	
	if (abs(dlat).gt.dall2) then
	    print *,'warning'
            print 107,jj,alat,blat(jj),dlat
        endif
107     format ('lat: ',i5,3f10.3)			
	

c       check if the obs on land

        if(cmask(ii,jj).lt.0.1)then
	nland=nland+1
	goto 800
	endif
	      

       if (isst.ge.999)then
         i_sst999=i_sst999+1
         go to 800
       endif
       
       if (isst.lt.-20 .or.isst.gt.400) then
          i_badsst=i_badsst+1
          print*,' bad sst:',cid,day,ilat,ilon,isst                         
          go to 800                                                     
        endif 	
	
        if(ihour.lt. 0 .or. ihour .gt. 2400)then
	  i_badhour=i_badhour+1
          print*,' bad hour:',year,mon,day,ihour
          go to 800
        endif 
		 
	
	
c       check the climatology	
            
        call intrp1(dstdev,362,362,180,xt,yt,alon,alat,dsd,ierr)
c            print*,'dsd=',dsd
	    if (ierr.ne.0) then
	      print *,'RED-STOP! SUBROUTINR-interp1: buoy stop 1001'
	      call exit(100)
	    endif
	call intrp1(doisst,362,362,180,xt,yt,alon,alat,doi,ierr)
c	    print*,'doi=',doi
	    if (ierr.ne.0) then
	      print *,'RED-STOP! SUBROUTINE-interp1: buoy stop 1002'
	      call exit(100)
	    endif
                                  
        anom = asst - gsst(ii,jj) 
	                             
!      write the good records to array 

       if(abs(anom).gt.dsd)then
         i_badclim=i_badclim+1
         go to 800
       endif
	              
      if(IDID .eq.1)then
        nship=nship+1
c******************************************************************************
        
c       make sure it is ship  i.e. not only IDID=1 but cid all letters
c          i_letter=0
c          read(cid(1:1),'(i1)', err=331)iii	  
c301	  read(cid(2:2),'(i1)', err=332)iii
c302	  read(cid(3:3),'(i1)', err=333)iii
c303	  read(cid(4:4),'(i1)', err=334)iii
c304	  read(cid(5:5),'(i1)', err=335)iii
c305	  read(cid(6:6),'(i1)', err=336)iii	  
c	  go to 339
	  
c331       i_letter=i_letter + 1
c          goto 301	
c332       i_letter=i_letter + 1
c          goto 302
c333       i_letter=i_letter + 1
c          goto 303	
c334       i_letter=i_letter + 1
c          goto 304
c335       i_letter=i_letter + 1	
c          goto 305
c336       i_letter=i_letter + 1
c
c339       if(i_letter .ge. ?)then
c	  goto 338
c	  else
c	  idbad_ship = idbad_ship + 1                                             
c          print*,' bad ship id:',cid 
c          goto 800
c	  endif
c***********************************************************************************

        if(cid(1:6).eq.'      '.or. cid(4:6).eq.'   ')then
          inoid_ship=inoid_ship+1
	  print*,inoid_ship,'cid(1:3)=',cid(1:3),'cid(4:6)=',cid(4:6)
	  goto 800
	elseif(cid(1:4).eq.'ship'.or.cid(1:4).eq.'SHIP')then
	iship=iship+1	
	goto 800
!       keep shipX 
!	elseif(cid(1:5).eq.'ship '.or.cid(1:5).eq.'SHIP ')then
          iship=iship+1
        else if(cid(1:4).eq.'plat'.or.cid(1:4).eq.'PLAT')then
          iplat=iplat+1
        else if(cid(1:4).eq.'bbxx'.or.cid(1:4).eq.'BBXX')then
          ibbxx=ibbxx+1
	 else if(cid(1:4).eq.'rigg'.or.cid(1:4).eq.'RIGG')then
	 irigg=irigg+1
          goto 800
        else if(cid(1:4).eq.'buoy'.or.cid(1:4).eq.'BUOY')then
	  ibuoy=ibuoy+1
          goto 800
	  
        else
	
c       make sure it is ship  i.e. not only IDID=1 but cid not all numbers
          read(cid,'(i6)', err=338)iii
	  idbad_ship = idbad_ship + 1                                             
            print*,' bad ship id:',cid  
	  goto 800  
	
	endif
	
	                  	
338       id(1:6) = cid(1:6)

          write (id(7:24),'(i4,i5,i6,i3)')ihour,ilat,ilon,isst
	  	  
          ndr_ship = ndr_ship + 1
	  
          if (ndr_ship.gt.maxdr)then
	    ndr_ship=maxdr
	    print 882
882         format ('warning too many obs: ndr_ship set to maxdr')
            goto 800
          endif
	  
          name_ship(ndr_ship) = id
	  idim_ship=ndr_ship
        
	  go to 800  
c        endif
 
c
c     end of put to ship array.
c                                    
c
c      if ID=2 or 3, put to buoy array 
c     
       else
c        if(IDID .eq. 2 .or. IDID .eq. 3)then    
         nbuoy=nbuoy+1  
	
	if(cid(1:6).eq.'      ')then                                  
          inoid_buoy=inoid_buoy+1
	go to 800  
	endif
	                                                   
        if (cid(1:4).eq.'buoy'.or.cid(1:4).eq.'BUOY')then                                
          ibuoy=ibuoy+1 
	  go to 800
	  endif
	                                                    	                                                      	                            
          read(cid,'(i6)',err=333)inum 
	  if (inum.ge.10000.and.inum.le.99999) go to 336
!           if (inum.ge.10000) go to 336
333         idbad_buoy = idbad_buoy + 1                                             
            print*,' bad buoy id:',cid                                         
          go to 800                                                 
          
	                                                    
336       write (id(1:6),'(i5,1x)') inum

c  if we want consider 6 digit buoy
!336       write (id(1:6),'(i6)') inum 
                                
          write (id(7:10),'(i4)')ihour
          write (id(11:24),'(i5,i6,i3)') ilat,ilon,isst
	  
          ndr_buoy = ndr_buoy + 1 
	  	                                                  
          if (ndr_buoy.gt.maxdr)then
	  ndr_buoy=maxdr
	  print 822
822       format ('warning too many obs: ndr_buoy set to maxdr')
          goto 800
          endif
	  	   
          name_buoy(ndr_buoy) = id 
	  idim_buoy=ndr_buoy 
      
      goto 800	                                                                                
      endif
                           
c
c      end of put to buoy array 
c           
 
  820 print 102,'nerr',year1,mon,day,ihour,ilat,ilon,IDID,iwind,cid,isst 
      nerr=nerr+1
      go to 800
102   format(a4,1x,3i2,i4,2i5,2i1,a6,18x,i3) 
                  
 8000 continue
 
      i_buoyship= nnn - i_idid - i_globe
      
      print*,'ijdmid:',ijdmid
      print*,'total obs(ship+buoy+ID>3) read on the day: nnn=',nnn
      print*,'total(ship+buoy) number of read errors:nerr=   ',nerr
      print*,'total obs with IDID>3 or =0....................',i_idid
      print*,'total obs(ship+buoy)not on the globe,i_globe=..',i_globe
      print*,'total obs(ship+buoy) read on the day=..........',
     1                                                        i_buoyship      
      print*,'total obs(ship+buoy) fail the land check=......',nland
      print*,'total obs(ship+buoy) with missing sst,i_sst999=',i_sst999
      print*,'total obs(ship+buoy) sst<-2 or sst>40,i_badsst=',i_badsst
      print*,'total obs(ship+buoy) hour<0 & hour>2400=.......',i_badhour
      print*,'total obs(ship+buoy) fail the clim check=......',i_badclim 
      print*,'inoid_ship=',inoid_ship
      print*,'inoid_buoy=',inoid_buoy
                             
      print 80,inoid_ship,iship,iplat,ibbxx
   80 format (/,
     1        ' number of ship obs without id   =',i5/,
     2        ' number of ship obs with "ship"  =',i5/,
     3        ' number of ship obs with "plat"  =',i5/,
     3        ' number of ship obs with "bbxx"  =',i5/)
c       print 84,idbad_ship                                                
c   84  format (/,                   
c     1 ' number of ship obs with bad id =',i5)
   
      print*,' '
      print*,'total good ship obs left = ....................',idim_ship
      print*,' '
      
      print*,'number of buoy obs without id:  inoid_buoy=   ',inoid_buoy                 
      print*,'number of buoy obs with id "buoy":  ibuoy=    ',ibuoy             
      print 83,idbad_buoy                                                
   83 format (' number of buoy obs with bad id =............',i5)
      print 88,idbad_ship                                                
   88 format (' number of ship obs with bad id =............',i5)
      print*,' '
      print*,'total good buoy obs left =.....................',idim_buoy
     
      print*,' '      
      print*,'check if total obs - obs left = obs throw away:',
     1 nnn - i_globe - nland - i_badsst - i_sst999 -  
     2 i_badhour - i_badclim -
     3 idim_ship - inoid_ship - iship - 
     4 idbad_buoy -idbad_ship - idim_buoy - i_idid -
     5 inoid_buoy - ibuoy -
     6 iplat - ibbxx - irigg
     
c      calculate the ratio
       rland=100.*float(nland)/float(i_buoyship)
       
       igood=idim_ship + idim_buoy
       ibad=i_badclim
c       ibad=i_badclims + i_badclimb
       
       itot = igood + ibad + idbad_buoy
       rgood = 100.*float(igood)/float(itot)
       rbad  = 100.*float(i_badclim) /float(itot) 
c       rbad  = 100.*float(i_badclimb) /float(idim_buoy)
c       rbad  = 100.*float(i_badclims) /float(idim_ship)
       
       Print*, ' '   
       print 106,itot,ibad,nland,rgood,rbad,rland
106    format ('buoyship : total obs =',i10,3x,'bad obs =',i8,3x,
     1 'land obs =',i8/'  % good sst=',f10.5,3x,
     2 '% bad sst =',f10.5,3x,'% land sst =',f10.5)
     
c       write daily buoy ship obs number for checking     
        open(789,file='/raid2/sstday/buoyship/buoy_ship_obs.out',
     1           form='formatted')
	write(789,678)iyrmid, immid, idmid,idim_ship,idim_buoy
678     format (3i4, 2i14)     
      
      if (nship.eq.0 .or. nbuoy.eq.0) go to 1000
      
**************************************************************  
      iwarn=0
         
      call buoyshipdt(1,iyrmid,immid,idmid,name_buoy,idim_buoy,
     1                doisst,dstdev,maxdr,ax1,ay1,blat,blon,isup)
c     caculate buoy sobs coverage 
      cover=100.0*float(isup)/sea_ict
      
      print*,'buoy sobs coverage=',cover      
      if(cover.lt.cov_buoyship)then 
      print 555,cover
555   format ('RED-STOP! BUOYSHIP-MAIN',3x,
     1  ' Buoy sobs coverage too low, coverage=',f5.2)
c      print*, 'RED-STOP! BUOYSHIP-MAIN',
c     1 ' Buoy sobs coverage too low, coverage=',cover
      call exit (100) 
      endif 
      
      if(cover. ge. cov_buoyship .and. cover.le.cov_buoy)then
      iwarn = 1
      print 888,cover
888   format ('YELLOW-WARNING! BUOYSHIP-MAIN',3x,
     1  ' Buoy sobs coverage too low, coverage=',f5.2) 
c      print*, 'YELLOW-WARNING! BUOYSHIP-MAIN:',
c     1 ' Buoy sobs coverage too low, coverage=',cover
c      call exit (10) 
      endif    
                                      
      call buoyshipdt(2,iyrmid,immid,idmid,name_ship,idim_ship,
     1                doisst,dstdev,maxdr,ax1,ay1,blat,blon,isup)
c     caculate ship sobs coverage 
      cover=100.0*float(isup)/sea_ict
      print*,'ship sobs coverage=',cover
      if(cover.lt.cov_buoyship)then 
      print 777,cover
777   format ('RED-STOP! BUOYSHIP-MAIN',3x,
     1  ' Ship sobs coverage too low, coverage=',f5.2)      
c      print*, 'RED-STOP! BUOYSHIP-MAIN:',
c     1 ' Ship sobs coverage too low, coverage=',cover
      call exit (100)  
      endif
      
      if(cover. ge. cov_buoyship .and. cover.le.cov_ship)then
      iwarn = 1
      print 999,cover
999   format ('YELLOW-WARNING! BUOYSHIP-MAIN',3x,
     1  ' Ship sobs coverage too low, coverage=',f5.2) 
c      print*, 'YELLOW-WARNING! BUOYSHIP-MAIN:',
c     1 ' Ship sobs coverage too low, coverage=',cover
c      call exit (10) 
      endif    
     
      call timer (itime2)
      tsec = float(itime2-itime1)*.01
      print *,tsec,' seconds for complete buoy ship QC code'

      go to 9999
      
 1000 print 701                                                         
  701 format ('RED-STOP! BUOYSHIP-MAIN: 
     1 that day not available in archive, 
     2 date not match the date in fiile')   
      call exit(100) 
      
c1234  print*,'RED-STOP BUOYSHIP-MAIN: ',
c     1       'Buoy ship input file does not exist ?????????'
c      call exit (100)

1234  print*,'YELLOW-WARNING! BUOYSHIP-MAIN: ',
     1       'Buoy ship input file does not exist ?????????'
      call exit (10)
      
1235  print*,'RED-STOP BUOYSHIP-MAIN:', 
     1       'first guess does not exist ?????????'    
      call exit (100)        
           
 5000 print 5001
 5001 format('RED-STOP! BUOYSHIP-MAIN:
     1        unexpected end of oisst firstguess')
      call exit (100)
      
 5500 print 5002
 5002 format('RED-STOP! BUOYSHIP-MAIN!
     1        unexpected end of file for stdev')
      call exit (100)      
      
 1500 print 1501
 1501 format('RED-STOP! BUOYSHIP-SUBROUTINE-dayclm!
     1        interpolation error dayclm')
      call exit (100)
      
 1600 print 1601
 1601 format('RED-STOP! BUOYSHIP-SUBROUTINE-intrp:
     1        interpolation error intrp ')       
      call exit (100)
      
      close(21)
            
9999  if (iwarn.eq.1) then
        print *, 'YELLOW-WARNING! COVERAGE LOW - buoyship-MAIN:'
        call exit (10)
      else
      print*,'GREEN-SUCCESSFUL! buoyship MAIN:'
      call exit(1)
      endif
      end

c--------------------------------------------------------------------------------

      integer*2 function compar(arg1,arg2)
      character*24 arg1,arg2
      if(arg1.lt.arg2)then
        compar=-1
      else if(arg1.eq.arg2)then
        compar=0
      else
        compar=1
      endif
      return
      end

c---------------------------------------------------------------------------------
c   subprogram documentation block                                    
c                .      .    .                                       .  
c   subprogram:  buoyshipdt_daily    quality control buoy data and output       
c   prgmmr: r.w. reynolds    org: w/np24     date: 1990-12-28             
c                                                                       
c   abstract:  In the main, the buoy obs passed the simple QC(such as on land,
c            lat lon are within the globe, sst not mssing, ID ok ...) are stored in 
c            an array called name_buoy(idim_buoy).The array includes sst, 
c	     position(latitude and longitude), date, time and buoy call sign 
c            or identification (id).   
c   
c            In this subroutine, first qsort buoy_name, get rid of the duplicated
c            obs. then, the data are quality controlled(such as speed fix,
c            within the climatology...). the quality controlled data are 
c            written out for use in the next program: superins.f  
c                 
c   all observations are stored in id and jdr. the observations         
c   for each id are stored in ldr with quality control flags in         
c   iflag.  observations passing the quality control steps are          
c   stored in mdr.                                                      
c                                                                       
c program history log:                                                  
c   1990-12-28  richard w. reynolds                                       
c   1994-07-25  diane c. marsico - modified array sizes for direct    
c                                  access reads due to change in size 
c                                  and attributes of insitu archive   
c   1996-12-04  diane c. stokes  - modified to read daily sst-only files
c   1998-04-20  diane c. stokes  - 4-digit years.  y2k compliant
c                                  integer*2 and integer*4 to integer 
c                                  (was non-standard)
c   2000-02-01  Diane C. Stokes  - move to IBM SP
c                                - changed gross check of max sst to 40
c                                - keep hour in hundredths (was tenths
c                                  for i*2 on ibm.  new buoys reporting
c                                  more than once per hour now.  more
c                                  accurate time helps speed check)
c   2005-01-20  Chunying Liu     - move land check to the main
c                                - move read weekly buoy ship data to the main
c                                - Add duplicated check and get rid off the 
c                                  duplicated records
c
c                                                                       
c usage:    call buoydt(iyrst,imost,idast,iyrend,imoend,idaend,ndays,
c     1                    name_buoy,idim_buoy,clima1,clims1,iarcdy_buoy,
c     2                    buoy_file_out,sea_mask)
c                                                                            
c   input argument list:                                                
c     iyrst,imonst,idast - starting day of data to be extracted.                  
c              - the day is yyyy,mm,dd. 
c     iyrst,imonst,idast - ending day of data to be extracted.                  
c              - the day is yyyy,mm,dd
c     iyrmid,imonmid,idamid - mid day of the week to be extracted.                  
c              - the day is yyyy,mm,dd
c     clima1   - the 1 degree resolution mean sst climatology for       
c              - the center of the period of interest.                  
c     clims1   - the 1 degree resolution standard deviation of the      
c              - sst, for center of the period of interest,             
c              - times smult.                                           
c              - (presently smult=3.5 in the main program )             
c              - the grid for both clima1 and clims1 is centered on     
c              - the half degree.  the first index is longitude         
c              - from 0.5e to 359.5e (range 1 to 360).  the second      
c              - index is latitude from -89.5 (89.5s) to 89.5 (89.5n)   
c              - (range 1 to 180).                                                                                                        
c       
c                                                                       
c   output files:                                                       
c     buoy_file_out  - quality control buoy data.     
c                                                    
c                                                                       
c   subprograms called:                                                 
c     unique:  - stat, spdfix, sstfix, dupfix, flag, longfx             
c                                                                       
c     library:                                                          
c       w3lib  -   w3fs26                                        
c                                                                       
c                                                                       
c   other important variables:                                          
c 
c     maxdr    -  the maximum number of observations which can be used  
c              -  by the subroutine; presently 2,000,000
c     name     -  buoy observations pass from the main
c     ndr      -  number of buoy obs pass from the main                  
c     idr      -  the name(ndr) is sorted and get rid of the dupilcated obs, 
c                 and put to idr.                              
c              -  the first six characters are the id,                  
c              -  the next two characters are the relative day for the     
c              -  period, the last three characters are the hour         
c              -  times 100.                                             
c              -  the size of idr is maxdr + 1                        
c     idr      -  character*12 array containing packed observations     
c              -  to be sorted by orders                                
c              -  the first six characters are the id,                  
c              -  the next two characters are the relative day for the     
c              -  period, the last three characters are the hour         
c              -  times 100.                                             
c              -  the size of id is maxdr + 1                           
c     jdr      -  a two dimensional integer array.                    
c              -  the first index corresponds to the index for id       
c              -  the second index corresponds to four variables        
c              -  associated with the observation in id                 
c              -    index = 1 is the latitude in degrees * 100          
c              -            range 90s (value -9000) to 90n              
c              -            (value 9000).                               
c              -    index = 2 is the longitude in degrees * 100         
c              -            range 180w (value -18000) to 180e           
c              -            (value 18000).                              
c              -    index = 3 is the sst in degrees * 10                
c              -    index = 4 is the hour of the observation * 100      
c              -            relative to the start date (ijdst)          
c      ldr     -  a two dimensional integer array: ldr(4,2000)        
c              -  this array is arranged in a similar way to jdr        
c              -  except the observations in ldr are ordered in time    
c              -  (by the first index of the arrary) and the obs        
c              -  are for only one id.  also the longitude values       
c              -  range from either 360w (value -36000) to 0e (value    
c              -  0) or from 180w (value -18000) to 180e (value         
c              -  18000) depending on the id (see subroutine longfx).   
c      ict     -  number of obs in ldr.                        
c              -  the present maximum is 2000.                          
c      mdr     -  a two dimensional integer array: mdr(4,2000)        
c              -  this array is similar to ldr but consists only of     
c              -  quality controlled observations.                            
c      jct     -  number of obs in mdr.                        
c              -  the present maximum is 2000.                          
c      iflag   -  integer array.  initially set to 0.  1 is added     
c              -  to iflag(i) for bad speed; 10 is added to iflag       
c              -  for bad sst; 100 is added to iflag for duplicate ob   
c              -  the index of iflag corresponds to the first index of  
c              -  ldr                                                   
c                                                                       
c    summary variables for each id                                      
c      amean   -  array of 4.  the mean latitude, longitude, sst and    
c              -  speed (corresponding to indices 1 through 4,          
c              -  respectively) for the quality controlled              
c              -  observations in mdr.                                  
c      stdev   -  array of 4.  the standard deviation of latitude,      
c              -  longitude, sst and speed for the quality controlled   
c              -  observations in mdr                                   
c      amax    -  array of 4.  the maximum absolute jump in latitude,   
c              -  longitude, sst and speed for the quality controlled   
c              -  observations in mdr                                   
c              -  note: in amean, stdev and amax.  the first three      
c              -  variables in the array are in degrees,                
c              -  the last variable is in m/s.                          
c      nprob   -  flag array of 4.  the first value flags position,     
c              -  the second the number of observations,                
c              -  the third sst, the fourth speed.                      
c              -  nprob is a counter of the number of problems found    
c              -  in the data.  if nprob = 0 no problems were found.    
c      mprob   -  equal to nprob(1) + nprob(2) + nprob(3) + nprob(4)    
c              -  mprob = 0 indicates all observations in mdr were ok.  
c              -  if ierr=1 on return from longfx: nprob(1)=nprob(1)+1  
c              -  if ierr=1 on return from sstfix: nprob(3)=nprob(3)+1  
c              -  if ierr=1 on return from spdffx: nprob(4)=nprob(4)+1  
c              -  if number of good obs to total obs is less discar     
c              -    (presently set to 0.5): nprob(2) = nprob(2)+1       
c                                                                       
c   language: fortran 90 
c   machine:  Red hat linux
c                                                                       
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc                                                                
           
      subroutine buoyshipdt(iu,iyrmid,immid,idmid,name,ndr,clima1,
     1                      clims1,maxdr,ax1,ay1,blat,blon,isup)
      parameter (nbig=10000)
      dimension clima1(362,180),clims1(362,180)                                                                                        
      character*24 name(maxdr) 
      character*6 cid
      character*8 file_obs 
      integer dim                                                                                                                                     
      external compar
      integer*2 compar
      integer iw3jdn
      dimension num(1440,720)
      real sst(1440,720)
      dimension wsst(nbig),wlat(nbig),wlon(nbig),wnum(nbig)
      dimension blat(720),blon(1440)
      character*45 pathoi
      logical lexist
    
      character*8 ctype(2)
      data ctype /'    buoy','    ship'/
      
      character*4 ctyp(2)
      data ctyp /'buoy','ship'/
      
      undef = -9999.
            
      do i=1,1440
      do j=1,720
      num(i,j)=0
      sst(i,j)=0
      enddo
      enddo
                    
      ix=iu+50
      iw=iu+60
      iv=iu+70
            
      write (iv) iyrmid,immid,idmid,ctype(iu)                   
                      
      call qsort(name,ndr,24,compar)
      
c************************************************************************ 
c   duplicate check 
       
       dim=0
       name(ndr+1)=name(1)
       
       do i=2,ndr + 1
       j=i-1
       if(name(i).ne.name(j))then
         dim=dim+1
         write(ix,666)name(j)
666      format(a24) 
      
         read(name(j),888)cid,ilat,ilon,isst
888      format(a6,4x,i5,i6,i3)       
         alat=0.01*ilat
         alon=0.01*ilon
         asst=0.1*isst

c        for GIS map, convert lon from 0~360 to -180~180	 
	 if(alon.gt.180)then
	 alon_gis=alon-360
	 else
          alon_gis=alon
	 endif
	 
c        for ships, iu=2	 
	 if(iu .eq.2)then
	 write(44,999)alon_gis,alat,asst,cid
	 endif
	 
c  output obs in GIS format	 
c        for buoys, iu=1	 
	 if(iu.eq.1)then
	 read(cid(3:3),'(i1)')itmp
	 idrift = 1 + itmp/5                                               
c        idrift = 1 for moored buoy; idrift = 2 for drifting buoy
	 
	   if(idrift .eq.1)then 
           write(22,999)alon_gis,alat,asst,cid 
           else       
           write(33,999)alon_gis,alat,asst,cid
           endif
	 
	 endif	 
	 	           
999      format(f7.2,',',f8.2,',',f5.1,',',a10) 	 	 
       
c      caculate the row and col number of this good obs 

c         ay1 = -89.875
c         ax1 = 0.125      
                                                          
       	 ii = 1 + nint(4.*(alon-ax1))
	 if (ii.eq.0) ii = 1
         if (ii.eq.1441) ii = 1440
		
         jj = 1 + nint(4.*(alat-ay1))
         if (jj.eq.0) jj = 1
         if (jj.gt.720) jj = 720
	
c     add this obs to the right grid box
       
         num(ii,jj)=num(ii,jj)+ 1
         sst(ii,jj)=sst(ii,jj)+ asst
     
       endif
       enddo
     
       print*,' '
       print*, 'number of obs that duplicated: '
       print 777,ctype(iu),iyrmid,immid,idmid, ndr - dim
      
777    format(a8,'_obs:'i5,2i3,i6) 

c      write out the total buoy or ship obs for each day.
c      it is cat to a big file in the shell  
       file_obs = ctyp(iu)//'_obs'
c       print*,'file_obs=',file_obs
       open(iu,file=file_obs,status='unknown')
       write(iu,777)ctyp(iu),iyrmid,immid,idmid,dim            
       
c************************************************************************          

c      caculate sst in one grid box, ie. super obs.  And write sobs to a one big array    
       
       i_sumnum=0
       
       do i=1,1440
       do j=1,720
       if(num(i,j).gt.0)then
	  i_sumnum = i_sumnum + num(i,j)
	  sst(i,j)=sst(i,j)/float(num(i,j))
          else
	  sst(i,j)=undef
       endif
       enddo
       enddo 
       
c       print*,'i_sumnum=',i_sumnum
              
	ict=0
        isup=0
	iwrt = 0               
	do i=1,1440
        do j=1,720
	if(num(i,j).gt.0)then
	ict=ict+1	
	wnum(ict)=float(num(i,j))
        wsst(ict)=sst(i,j)
	wlat(ict)=blat(j)
	wlon(ict)=blon(i)
c	  if(wsst(ict).eq.14.6)then
c	  print*, '*****************'
c	  print*, wsst(ict),wlat(ict),wlon(ict)
c	  endif 
        endif
	
	if(ict .eq. nbig)then
c	  icts = ict
	  iwrt = iwrt + 1
	  write(iv)  ict
	  write(iv) (wnum(ii),ii=1,ict)                                    
          write(iv) (wsst(ii),ii=1,ict)                                    
          write(iv) (wlat(ii),ii=1,ict)                                    
          write(iv) (wlon(ii),ii=1,ict) 
	
	  call maxmin (wnum,ict,1,undef,'    wnum')
	  call maxmin (wsst,ict,1,undef,'    wsst')
	  call maxmin (wlat,ict,1,undef,'    wlat')
	  call maxmin (wlon,ict,1,undef,'    wlon')                                   
                                                                                             
          isup = isup + ict 
	  ict=0
	endif  	                                                
                                                                            
       enddo
       enddo
       
        if(ict.gt.0)then
        isup=isup+ict
	iwrt = iwrt + 1
	icts = ict
	write(iv) ict
        write(iv) (wnum(ii),ii=1,ict)                                    
        write(iv) (wsst(ii),ii=1,ict)                                    
        write(iv) (wlat(ii),ii=1,ict)                                    
        write(iv) (wlon(ii),ii=1,ict)
	endif 
	
	call maxmin (wnum,ict,1,undef,'    wnum')
	call maxmin (wsst,ict,1,undef,'    wsst')
	call maxmin (wlat,ict,1,undef,'    wlat')
	call maxmin (wlon,ict,1,undef,'    wlon')
	
c     Write out the grid obs SST
      
      write (iw) iyrmid,immid,idmid,sst
      
      call maxmin (sst,1440,720,undef,ctype(iu))
       
      Print*, ' '
      print 111,ctype(iu),isup,icts,iwrt
111   format (a8,3x,'number sup obs =',i10,3x,'last ict =',i8,
     1  3x,'num writes =',i3)
     
c      caculate buoy or ship obs coverage 
c      cover=100.0*float(isup)/698057.0
c      if(cover.lt.0.1)then 
c      print*, 'YELLOW-WARNING! BUOYSHIP-SUBROUTINE-buoyshipdt',
c     1 ctype(iu),' sobs coverage too low, cover=',cover 
c      Print*, ctype(iu), ' total obs =', i_sumnum  
c      endif
         
      return
      end   
     
      
      subroutine intrp1(cn,imc,ic,jc,cx,cy,fx,fy,fn,ierr)
      dimension cn(imc,jc),cx(ic),cy(jc)
      if (fx.lt.cx(1).or.fx.gt.cx(ic)) go to 10
      if (fy.lt.cy(1).or.fy.gt.cy(jc)) go to 10
      do 110 l=1,jc
      if (cy(l).lt.fy) go to 110
      jn = l
      js = l-1
      if (js.eq.0) jn = 2
      if (js.eq.0) js = 1
      go to 111
  110 continue
      jn = jc
      js = jc - 1
  111 continue
      do 120 l=1,ic
      if (cx(l).lt.fx) go to 120
      ie = l
      iw = l-1
      if (iw.eq.0) ie = 2
      if (iw.eq.0) iw = 1
      go to 121
  120 continue
      ie = ic
      iw = ic - 1
  121 continue
      a = (fx - cx(iw))
      b = (cx(ie) - fx)
      c = fy - cy(js)
      d = cy(jn) - fy
      ac = a*c 
      bc = b*c 
      ad = a*d 
      bd = b*d
      top = ac*cn(ie,jn) + bc*cn(iw,jn) + ad*cn(ie,js) + bd*cn(iw,js)
      bot = ac + bc + ad + bd
      ierr = 0
      fn = top/bot
      return
c
c     no interpolated value
c
   10 print 15
   15 format (' problem in intrp1: fx or fy out of range;',
     1 '   no interpolated value')
      print 20,cx(1),cx(ic),fx
   20 format (' cx(1) =',f10.3,3x,'cx(ic) =',f10.3,3x,'fx =',f10.3)
      print 25,cy(1),cy(jc),fy
   25 format (' cy(1) =',f10.3,3x,'cy(jc) =',f10.3,3x,'fy =',f10.3)
      ierr = 1
      return
      end  
            

      subroutine linfil (sst,wk,ls,lwk,imx,imy,default)
      dimension ls(imx,imy),lwk(imx,imy),wk(imx,imy),sst(imx,imy)
c      this routine fills ssts by linear interpolation along lines
c      of latitude. It assumes a regular grid which repeats in longitude.
c      the filled in values are smoothed by 3-time application 
c         of a north-south 1-2-1 filter
c      sst is the array of analyzed sst
c      wk is a temporary work array
c      ls is the land sea array: ocean = 1, land = 0
c      lwk is the work land sea array: ocean = 1, land = 0
c      sst values are filled in for ls values = 0, 
c        otherwise they are not changed
c     if entire row is missing fill in with default value
c
      imm = imx - 1
      jmm = imy - 1
c
      do j=1,imy
        isum = 0
        do i=1,imx
	  wk(i,j) = sst(i,j)
	  lwk(i,j) = ls(i,j)
	  isum = isum + lwk(i,j)
        enddo
	if (isum.eq.0) then
          do i=1,imx
	    wk(i,j) = default
	    sst(i,j) = default
	    lwk(i,j) = 1
          enddo
	endif
      enddo
c      iprt = 16
c      print *,(lwk(i,iprt),i=1,360)
c	
      do j=1,imy
	do i=1,imx
          if (lwk(i,j).eq.0) then
c
c    find left point
c  
	    isub = 0
            is = i
            do ict=1,imm
              is = is - 1
              if (is.lt.1) then
                is = is + imx
                isub = isub - imx
              endif
              if (lwk(is,j).ne.0) go to 10
            enddo
c     
c     whole row missing stop
            print*,'RED-STOP! SUNROUTINE-linfil'
            print *,'whole row missing: stop 101   i =',ict
            call exit(100)
c
c    find right point
c  
   10       iadd = 0
            ie = i
            do ict=1,imm
              ie = ie + 1
              if (ie.gt.imx) then
                ie = ie - imx
                iadd = iadd + imx
              endif
              if (lwk(ie,j).ne.0) go to 20
            enddo
c     
c     whole row missing stop
            print*,'RED-STOP! SUNROUTINE-linfil'
            print *,'whole row missing: stop 102'
            call exit(100)
	    
   20       re = float(ie+iadd-i)
            rs = float(i-is-isub)
            rall = rs + re
            wk(i,j) = (wk(ie,j)*rs + wk(is,j)*re)/rall
c	    if (j.eq.iprt) then
c	      print 102,i,is,isub,ie,iadd,j
c  102         format ('i =',i5,3x,'is =',i5,3x,'isub =',i5,3x,
c     1        'ie =',i5,3x,'iadd =',i5,3x,'j =',i5)
c	      print 103,rs,re,rall
c  103         format ('rs =',f8.1,3x,'re =',f8.1,3x,'rall =',f8.1)
c     1       'ie =',i5,3x,'iadd =',i5)
c	      print 104,sst(i,j),wk(i,j),wk(is,j),wk(ie,j)
c  104         format ('sst =',f8.1,3x,'wk(i,j) =',f8.1,3x,'wk(is,j) =',
c     1        f8.1,3x,'wk(ie,j) =',f8.1)
c            endif
          endif
        enddo
      enddo
c23456
c      do j=iprt,iprt
c      do j=1,imy
c        do i=1,imx
c	  if (wk(i,j).lt.-99.) print 109,i,j,lwk(i,j),wk(i,j)
c  109     format ('i =',i5,3x,'j =',i5,3x,'lwk =',i5,3x,'wk =',f8.2)
c        enddo
c      enddo
c     replace a values with interpolated values with j index 1-2-1 smoothing
c
      do ism = 1,3
        do j=2,jmm
          jm = j - 1
	  jp = j + 1
          do i=1,imx
            if (lwk(i,j).eq.0) then
	      wk(i,j) = 0.25*wk(i,jp) + 0.5*wk(i,j) + 0.25*wk(i,jm)
	    endif
          enddo
        enddo
      enddo
      do i=1,imx
        do j=1,imy
          if (lwk(i,j).eq.0) then
	    sst(i,j) = wk(i,j) 
	  endif
        enddo
      enddo
      return
      end
     
      
       subroutine dayclm (stdev,imo,ida,dclim,ierr)
c    stdev   - field of the 12 months of climatology                  
c              - dimension (12,360,180)                                  
c              - the first index is the month,                          
c              - from january (= 1) to december (=12)                   
c              - the second index is longitude: (0.5E to 359.5e) 
c                          ...corrected lon range in comment 10 Feb 2000
c              - the third index is latitude: (89.5s to 89.5n)              
c     imo      - month of desired interpolated climatology              
c     ida      - day of desired interpolated climatology                
c                                                                       
c   output argument list:                                               
c     dclim    - field of the temporally interpolated                   
c              - climatology for imo and ida                            
c              - dimension (362,180)                                     
c              - the first index is longitude: (0.5w to 360.5e) 
c              - the second index is latitude: (89.5s to 89.5n)         
c              - note: if extra longitude values are requested,
c              -       dclim(1,j) = dclim(361,j)   
c              -       dclim(362,j) = dclim(2,j) 
c     ierr     -  equal to 0 if interpolated field found                
c              -  equal to 1 if no interpolated field because of        
c              -  bad imo or ida or                  
c                                                                       
c   output files:                                                       
c     fort.06  - printout                                               
c                                                                       
c remarks:  
c                                                                       
c attributes:                                                           
c   language: fortran 77                                                
c   machine:  cray                                                       
c                                                                       
c$$$                                                                    
      integer*4 ndays(12)
      dimension stdev(12,360,180)
      dimension dclim(362,180)
      data ndays/31,28,31,30,31,30,31,31,30,31,30,31/
c  change february 29 to february 28: effect of leap year ignored       
      ierr = 0
c
      if (imo.eq.2.and.ida.eq.29) ida = 28
c                                                                       
c      print 10, imo,ida
c   10 format('interpolated climate for month = ',i3,3x,'day =',i3)
c  check for bad date                                                   
      if (imo.lt.1.or.imo.gt.12.or.ida.lt.1.or.ida.gt.ndays(imo)) then
      print 222
  222 format (' warning interpolation error in dclim')
      ierr = 1
      return
      endif
      halfm1 = real(ndays(imo))/2.
      if (ida.le.int(halfm1)) then
        if (imo.eq.1) then
          jmo = 12
        else
          jmo = imo-1
        endif
        d = halfm1 - real(ida) + .5
      else
        if (imo.eq.12) then
          jmo = 1
        else
          jmo = imo+1
        endif
        d = real(ida) - halfm1 - .5
      endif
      halfm2 = real(ndays(jmo))/2.
      span = halfm1+halfm2
      do i=1,360
        ip = i + 1
        do j=1,180
	  t1 = stdev(imo,i,j)
          t2 = stdev(jmo,i,j)
          dclim(ip,j) = ((t2-t1)/span)*d + t1
        enddo
      enddo
      do j=1,180
        dclim(1,j)   = dclim(361,j)
        dclim(362,j) = dclim(2,j)
      enddo
      return
      end
      
      SUBROUTINE GETFG (IUN,IMX,IMY,IERR,iday,NDAYS,gsst,undef)
      DIMENSION GSST(IMX,IMY)     
      IERR = 0
C - READING IN THE FIRST-GUESS
      READ (IUN,END=6000) jyr,jmo,jda,gsst
      PRINT 10,jyr,jmo,jda
   10 FORMAT (' GUESS DATE:  YEAR =',I5,3X,'MONTH =',I3,
     1 3X,'DAY =',I3)
      jday =  iw3jdn (jyr,jmo,jda)
      if (iday-jday.ne.ndays) then
        print *,'FIRST GUESS DATE ERROR: Program ends'
	go to 6000
      endif
      RETURN
 6000 PRINT 7000
 7000 FORMAT(' ERROR! - NO FIRST-GUESS: IERR=1 IN GETFG')
      IERR = 1
      RETURN
      END
      
      include '/home/cliu/lib/w3lib/iw3jdn.f'
      include '/home/cliu/lib/w3lib/w3fs26.f'
      include '/home/cliu/lib/maxmin.f'
      








