ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c main program satellite_navy_daily_firstguessclim_6hr_col.f
c           use 8 day satellite files
c           use first guess as climatology instead of interpolat OI weekly sst
c                                                 .      .    .                                       .                                                                         
c abstract: read select fields: itype,iscr,iyr,imo,ilat,ilon,iday,ihr,isst 
c           from two 6 hour satellite observation files from OSDPD.
c           these data are extract in each day and are separated into  
c           day time and night time categories.
c       
c           the data are quality controlled by comparing the sea surface 
c           temperatures against climatology(monthly mean and monthly 
c           standard deviation).  
c           calculate the average of SST, lat, lon, standard deviation,
c           number of observation in each 1 degree box.
c           the output is day time and night time super obs.   
c   
c           The main code reads the satellite observations, land mask, 
c           and climatology data. Then it does a preliminary quality contol
c           (lat lon are within the globe, sst not mssing, sst between -2 and 40...). 
c           Then the satellite observations are put into dsat array and 
c           nsat array seperately, write out 
c           for the climatology check and calculate the 
c           the super obs.                       
c                                                                       
c program history log:                                                  
c                                           
c   2005-05-20  richard w. reynolds,  Chunying Liu  
c
c  main program: satellite_navy.f
c
c  input file:    sea mask
c     sea_mask_in    - /raid/cliu/oiweekly/data/lstags.onedeg.dat
c         
c                sst climatology(12 months; 1 deg grid; 90s-90n) :
c     file_clim_in   -  /raid/cliu/oiweekly/data/aoi.61.90.clim
c
c               sst st. dev sst climatology (12 months; 2 deg grid; - 80s-80n) 
c     file_stdev_in  - /raid/cliu/oiweekly/data/stdev2d
c               
c               three days 6-hour satellite observation files from OSDPD.
c     file_in      - /raid2/cliu/satellite/navy/yyyy/NAVYOBS.Dddd
c     
c                                                                           
c  output files:  (pass from the shell script) 
c     file_dobs_out   -daily daytime ascii obs
c                     /raid2/sstday/YYYY/obs/navy/dsato.YYYYMMDD
c     file_nobs_out  -daily nighttime ascii obs
c                    /raid2/sstday/YYYY/obs/navy/nsato.YYYYMMDD
c     file_dgrid_out - daytime grid sst
c                   /raid2/sstday/grads/navy/daynavy.sst.YYYYMMDD
c     file_ngrid_out -nighttime grid sst
c                   /raid2/sstday/grads/navy/ntenavy.sst.YYYYMMDD
c     file_dgrid_num_out - dattime good obs numbers in a 1/4 grid box
c                   /raid2/sstday/grads/navy/daynavy.num.YYYYMMDD
c     file_ngrid_num_out - nighttime good obs number in a 1/4 grid box
c                   /raid2/sstday/grads/navy/ntenavy.num.YYYYMMDD                               
c                                                                       
c   subprograms called:                                                 
c     unique:  -  supersat                   
c     library:                                                          
c       w3lib  -  iw3jdn, qsort
c                                                                       
c   exit states:                                                        
c     cond =   3 - first 8 dayfile is not available
c              4 - second 8 dayfile is not available    
c             13 - premature end of file for climatology 
c             14 - premature end of file for stdev               
c             15 - interpolation error in dayclm1d                        
c             16 - interpolation error dayclm    
c             17 - interpolation error intrp
c                                                                       
c remarks:  subroutine supersat  calculate satellite superobs               
c                             
c                                  
c important variables:   
c     iyrst,imost,idast  - starting day of data to be extracted.                  
c                        - the day is yyyy,mm,dd     pass from the shell script.
c     iyrend,imoend,idaend - ending day of data to be extracted.                  
c                        - the day is yyyy,mm,dd     pass from the shell script.
c     iyrmid,immid,idmid - mid day of the week of analysis.                  
c                           - the day is yyyy,mm,dd  pass from the shell script.                                      
c     dsat      -  day time satellite observations, itype=151
c               -  character*18 array 
c               -  the first two characters are the relative day for the     
c               -  period, the next two characters are the hour.
c               -  character 5:18 are latitude, logitude, and sst.                       
c     dim_dsat  -  total day time satellite observations
c     nsat      -  night time satellite observations, itype=152
c               -  character*18 array 
c               -  the first two characters are the relative day for the     
c               -  period, the next two characters are the hour.
c               -  character 5:18 are latitude, logitude, and sst.                       
c     dim_nsat  -  total night time satellite observations
c     
c     clima1    - the 1 degree resolution mean sst climatology for       
c               - the center of the period of interest.                  
c     clims1    - the 1 degree resolution standard deviation of the      
c               - sst, for center of the period of interest,             
c               - times smult.                                           
c               - (presently smult=3.5 in the main program )             
c               - the grid for both clima1 and clims1 is centered on     
c               - the half degree.  the first index is longitude         
c               - from 0.5e to 359.5e (range 1 to 360).  the second      
c               - index is latitude from -89.5 (89.5s) to 89.5 (89.5n)   
c               - (range 1 to 180). 
c   sea_mask    - land sea tag. 1 degree, 0-360E, 90S-90N.   land=0, sea=1.                                                                                                                                                                                                                                       
c                                                                          
c   language: fortran 90 
c   machine:  Red hat Linux
c
c------------------------------------------------------------------------------------                                              
c   8 day satellite input data description from web site   
c   http://www2.ncdc.noaa.gov/docs/podug/html/c5/sec52-2.htm#not52216
c
c   Table 5.2.2.2-3. Format of the Eight Day SST Observation Unit. 
c
c   Halfword   Byte   Contents                       Range 
c   1         1       Type of Observation           129 to 255 
c   1         2       Source of Observation           0 to 255 
c   2         3       Year                            0 to 99 
c   2         4       Month                           1 to 12 
c   3         5-6     Latitude (+N,-S) x 100      -9000 to 9000 
c   4         7-8     Longitude (+E, -W) x 100   -18000 to 17999 
c   5         9       Day                             1 to 31 
c   5         10      Hour                            0 to 23 
c   6         11      Minute                          0 to 59 
c   6         12      Second                          0 to 59 
c   7         13-14   SST (degrees C x 10)          -20 to 350 
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
      
      parameter (imx=1440,imy=720)
      integer*2 IBUF(52)
      character*1 CBUF(104)
      equivalence(IBUF,CBUF)
      
      character*80 file_in,navyeotfg
      character*80 sea_mask_in,quarter_mask_in,file_stdev_in
      character*80 file_dobs_out,file_nobs_out
      character*80 file_dgrid_out,file_ngrid_out
      character*80 file_dsobs_out,file_nsobs_out
      
      
      dimension sea_mask(360,180), lsea_mask(360,180),cmask(imx,imy)
      integer itype,iscr,iyr,imo,ilat,ilon,iday,ihr,isst,year
      integer iyrmid,immid,idmid,irel
      
      parameter(imax=5000000)
      character*16 dsat(imax)
      character*16 nsat(imax)   
      real alat,alon
      integer dim_dsat,dim_nsat
      integer sea_ict
      dimension stdev(12,360,180),dstdev(362,180),wk(360,180),
     1          lwk(360,180)
      dimension blat(imy),blon(imx)
      dimension yt(180),xt(362)
      dimension gsst(imx,imy),sst(360,180)
      character*8 ctype(2)
      logical lexist
      
      call timer (itime1)
            
      read 666, quarter_mask_in,file_stdev_in,file_in,
     1          navyeotfg, 
     1          file_dobs_out,file_nobs_out,
     2          file_dgrid_out,file_ngrid_out,
     3          file_dsobs_out,file_nsobs_out

      
      read *,   iyrmid, immid, idmid
      read *,   isource 
      read *,   cov_sat
      read *,   cov_sat2
         
666   format(a80)

       if(isource.eq.7)then
       ctype(1)='dsat18  '
       ctype(2)='nsat18  '
       endif
       
       if(isource.eq.6)then
       ctype(1)='dsat17  '
       ctype(2)='nsat17  '
       endif
       
       if(isource.eq.12 .or. isource .eq.8)then
       ctype(1)='dmetop  '
       ctype(2)='nmetop  '
       endif
       
      
cliu      print*, 'sea  mask file:        ', sea_mask_in
      print*, 'quarter mask file:     ', quarter_mask_in
      print*, 'Monthly stdev file:    ', file_stdev_in
      print*, '6-hour sat file:       ', file_in
      print*, 'navy eot firstguess:   ', navyeotfg
      print*, 'daytime sat obs file:  ', file_dobs_out
      print*, 'nighttime sat obs file:', file_nobs_out
      
      print*, 'daysat sst grid file:  ', file_dgrid_out
      print*, 'ntesat sst grid file:  ', file_ngrid_out
      
      print*, 'daysat sobs file:      ', file_dsobs_out
      print*, 'ntesat sobs file:      ', file_nsobs_out
      
      print*, 'Year, month, day of each day: ', iyrmid, immid, idmid
      print*, 'satellite source:      ', isource 
      print*, 'satellite coverage :   ', cov_sat,cov_sat2    
c      write the daily obs
       open(51,file=file_dobs_out,form='formatted')
       open(52,file=file_nobs_out,form='formatted')

       
c      write grid sst      
       open(61,file=file_dgrid_out,form='unformatted')
       open(62,file=file_ngrid_out,form='unformatted')      
       
c      write sobs        
       open(71,file=file_dsobs_out,form='unformatted')
       open(72,file=file_nsobs_out,form='unformatted')
       
                                        
c    read in standard deviation climatology                             
c                                                                       
      smult = 3.5
c                                                                       
c    sst values are eliminated when the absolute value of the anomaly   
c    is greater than smult*the standard deviation of the climatology    
c    the minimum value of the standard deviation is 1.0 degrees c.      
c    the maximum value of the standard deviation is 4.5 degrees c.                                                                            

c    read in oi.v2 mask

cliu      open (3,file=sea_mask_in,form='unformatted',
cliu     1        access='direct',recl=4*360*180)

      undef = -9999.
cliu      read (3,rec=1) sea_mask
cliu      print *,'got land/sea mask: v2'
cliu      call maxmin (sea_mask,360,180,undef,'sea_mask') 
cliu      call maxmin (sea_mask,360,180,0.,'sea_mask')

cliu      do 420 i=1,360
cliu      do 420 j=1,180
cliu      lsea_mask(i,j)=nint(sea_mask(i,j))
cliu420   continue  


c     read quater degree mask

      open (30,file=quarter_mask_in,form='unformatted')
      read (30) cmask
      call maxmin (cmask,1440,720,undef,'land sea  ')
      call maxmin (cmask,1440,720,1.,'land pts  ')
      call maxmin (cmask,1440,720,0.,'ocean pts ')

c     count how may sea pixels to calculate buoy ship data coverage.      
      
      sea_ict=0
      do i=1,imx
      do j=1,imy
      if(cmask(i,j).eq.1.0)then
      sea_ict=sea_ict+cmask(i,j)
      endif
      enddo
      enddo
      
      print*,'sea_ict=',sea_ict

c
c     read in coads standard deviation for 1950-79
c
      open (4,file=file_stdev_in,form='unformatted')
      dfsd = 1.0
      dfoi = -1.8
      print *,'smult =',smult
      do imo=1,12
        read (4) iyr,jmon,sst
        print *,'base period =',iyr,'   month =',jmon
        call maxmin (sst,360,180,undef,'sd-orig ')

        do j=1,180
          do i=1,360
	    ss = sst(i,j)
	    if (ss.lt.1.0) ss = 1.0                                           
            if (ss.gt.4.5) ss = 4.5 
	    stmp = ss*smult                                          
            stdev(imo,i,j) = stmp
	    wk(i,j) = stmp
          enddo
        enddo
c        call maxmin (sst,360,180,undef,'sd-fill  ')
        if (imo.eq.1) call maxmin (wk ,360,180,undef,'sd-scale ')
      enddo
      
c     now interpolate stdev to the correct day

c     Feb. 29 is set to 28 in dayclm
      jmmid = immid
      jdmid = idmid      
      call dayclm (stdev,jmmid,jdmid,dstdev,ierr)
      call maxmin (dstdev,362,180,undef,'intr std')
      if (ierr.ne.0) then
	print *,'RED-STOP! SUBROUTINE-dayclm'
	call exit(100)
      endif
         
c  read in the first guess
     
       ijdmid = iw3jdn(iyrmid, immid, idmid)
       print 202,ijdmid,iyrmid, immid, idmid
     
202   format('Julian day=',i10,3x,'yr =',i5,3x,'mon =',i3,3x,'day =',i3)

      open(31,file=navyeotfg,form='unformatted',status='old',ERR=1235)

      ndays=1
      CALL GETFG (31,imx,imy,IERR,ijdmid,ndays,gsst,undef)
      call maxmin (gsst,imx,imy,undef,'gsst    ')
      
      If(IERR .EQ.1)THEN
      print*,'RED-STOP! SUBROUTINE-getfg' 
      CALL EXIT (100)
      ENDIF     
      
c----------------------------------------------------------------------      
c     calculated the 1/4 degree and 1 degree grid lon, lat

c      undef = -9999.

      dall = 0.25
      dall2 = 0.125

      ay1 = -89.875
      ax1 = 0.125
      
      do i=1,1440
        blon(i) = dall*float(i-1) + ax1
      enddo      
      call maxmin (blon,1440,1,undef,'blon    ')
      
      
      do j=1,720
       blat(j) = dall*float(j-1) + ay1
      enddo
c      print*,'aalat(91)=',aalat(91)
      call maxmin (blat,720,1,undef,'blat    ')
      
      xt1 = -0.5
      yt1 = -89.5
c      yt1=0.5
      
      dxy = 1.
      do i=1,362
        xt(i) = dxy*float(i-1) + xt1
      enddo
      call maxmin (xt,362,1,undef,'xt:1-deg')
      do j=1,180
        yt(j) = dxy*float(j-1) + yt1
      enddo
      call maxmin (yt,180,1,undef,'yt:1-deg')            
            
c---------------------------------------------------------------------------------      
c      read in the NAVY 6-hr satellite data       
       
       isst_min=-20
       isst_max=400
       
c     read in the first satellite file       
       
       dim_dsat=0
       dim_nsat=0

       
       n=0
       nland=0
       i_badclim=0
       i_globe=0
       i_badhour=0
       idbad_buoy = 0
       i_badsst=0
       iflag=0
       
       OPEN(81,FILE=file_in,form='unformatted',ACCESS='DIRECT',
     1      RECL=104,ERR=1234,status='old')         
        irec=1
	j=10
        i=5

333    read (81, rec =irec,err=303)IBUF
c       print*,'irec=',irec
       
        irec=irec+1
       
       
       itype=ichar(CBUF(j))
       iscr=ichar(CBUF(j-1))
       
       if(iscr.ne.isource)go to 333
       
!       print 33,i,j,ibuf(i),ibuf(i),itype,iscr
!33     format(3i8,o8,i8,i8)  
       
       IF(itype .eq.151 .or. itype .eq.152)THEN
       iyr=ichar(CBUF(j+2))
       imo=ichar(CBUF(j+1))
       ilat=ibuf(i+2)
       ilon=ibuf(i+3)
       iday=ichar(CBUF(j+8))
       ihr=ichar(CBUF(j+7))
       isst=ibuf(i+6)
c------------------------------------------------------------------------
c     convert year from 2 digital to 4 digital
       
       year=iyr+2000 
       if(iyr.ge.79)then
       year=iyr+1900
       endif 
        
c       ijdmid = iw3jdn(iyrmid, immid, idmid)
c       print*,ijdmid,iyrmid, immid, idmid
       	        
        ijd = iw3jdn(year,imo,iday)
c        print*,ijd,year,imo,iday,ijdmid
        n=n+1

        if(ijd.ne.ijdmid)go to 333        
	
c       No satellite obs |lat|>89.5
      
        if (iabs(ilat).gt.8950.or.abs(ilon).gt.18000)then
        i_globe=i_globe +1
        go to 333
	endif
            
c      convert ilon from -180 to 180E to 0-360E
       if(ilon.lt.0)ilon=ilon+36000
       
       
c       calculate the col & row number of each obs

        alat=0.01*ilat
	alon=0.01*ilon
	asst=0.1*isst	
	
	ii = 1 + nint(4.*(alon-ax1))
	if (ii.eq.0) ii = 1
        if (ii.eq.1441) ii = 1440
	dlon = alon-blon(ii)
		
	if (abs(dlon).gt.dall2) then
	    print *,'warning'
            print 109,ii,alon,blon(ii),dlon
        endif
109     format ('lon: ',i5,3f10.3)	
	
        jj = 1 + nint(4.*(alat-ay1))
        if (jj.eq.0) jj = 1
        if (jj.gt.720) jj = 720
	dlat = alat-blat(jj)
	
	if (abs(dlat).gt.dall2) then
	    print *,'warning'
            print 107,jj,alat,blat(jj),dlat
        endif
107     format ('lat: ',i5,3f10.3)			
	

c       check if the obs on land

        if(cmask(ii,jj).lt.0.1)then
	nland=nland+1
	goto 333
	endif
      	    
       
c      Do part of the quality control

c       if(iyr.lt.0.or.iyr.gt.99)then                                   
c          print*,' bad year:',iyr,imo,iday,ihr                           
c          go to 333                                                     
c        endif
	                                                           
c        if(imo.lt.1.or.imo.gt.12)then                                   
c          print*,' bad month:',iyr,imo,iday,ihr                          
c          go to 333                                                     
c        endif  
	                                                         
c        if(iday.lt.0.or.iday.gt.31)then                                   
c          print*,' bad day:',iyr,imo,iday,ihr                             
c          go to 333                                                     
c        endif 
	                                                          
        if(ihr.lt.0 .or. ihr.gt.24)then 
	  i_badhour=i_badhour+1                                
          print*,' bad hour:',iyr,imo,iday,ihr                            
          go to 333                                                     
        endif 
	                                                                                 	                                                          
        if (isst.lt.isst_min.or.isst.gt.isst_max)then
	  i_badsst=i_badsst+1
          print*,' bad sst:',iday,ilat,ilon,isst                          
          go to 333                                                     
        endif 
	
!	if(irec .le. 20)then
!       print 13, itype,iscr,iyr,imo,ilat,ilon,iday,ihr,isst
!13     format(1x,'type=',i3,3x,'source=', i3,3x,'year=',i4,3x,
!     1        'month=',i3,3x, 'lat=',i6,3x,'lon=',i6,3x,
!     2        'day=',i3,3x,'hour=',i3,3x,'sst=',i6,3x)
!       endif 

c       check the climatology	
            
        call intrp1(dstdev,362,362,180,xt,yt,alon,alat,dsd,ierr)
c            print*,'dsd=',dsd
	    if (ierr.ne.0) then
	      print *,'RED-STOP! SUBROUTINR-interp1'
	      call exit(100)
	    endif
                                  
        anom = asst - gsst(ii,jj) 
	                             
!      write the good records to array 

       if(abs(anom).gt.dsd)then
         i_badclim=i_badclim+1
         go to 333
       endif
	
	
	if(itype .eq.151)then
c	  dim_dsat=dim_dsat+1
	  if(dim_dsat .gt. imax)then
	    iflag=1
	  else
c	    print*,'???????dsat??????????'
c	    print 101,ihr,ilat,ilon,isst
            dim_dsat=dim_dsat+1
	    write(dsat(dim_dsat),101)ihr,ilat,ilon,isst
	  endif
	endif
	
	if(itype .eq.152)then
c	  dim_nsat=dim_nsat+1
	  if(dim_nsat .gt. imax)then
	    iflag=1
	  else
c	    print*,'???????nsat??????????'
c	    print 101,ihr,ilat,ilon,isst
            dim_nsat=dim_nsat+1
	    write(nsat(dim_nsat),101)ihr,ilat,ilon,isst
	  endif
	endif
	
		
101     format(i2,i5,i6,i3)
       
       endif
        
       goto 333
       
303    print*,'6 hour file total records read:     ',irec - 1
       print*,'day and nte obs from 6-hour files:  ',n
       print*,'total obs not on the globe,i_globe=..',i_globe
       print*,'total obs fail the land check=......',nland
       print*,'total obs sst<-2 or sst>40,i_badsst=',i_badsst
       print*,'total obs hour<0 & hour>2400=.......',i_badhour              
       print*,'total obs fail the clim check=.......',i_badclim
       print*,'dim_dsat=',dim_dsat
       print*,'dim_nsat=',dim_nsat
       
              
c      calculate the ratio

       rland=100.*float(nland)/float(n-i_globe)
       
       igood=dim_dsat + dim_nsat
       ibad=i_badclim
c       ibad=i_badclims + i_badclimb
       
       itot = igood + ibad 
       rgood = 100.*float(igood)/float(itot)
       rbad  = 100.*float(i_badclim) /float(itot) 
c       rbad  = 100.*float(i_badclimb) /float(idim_buoy)
c       rbad  = 100.*float(i_badclims) /float(idim_ship)
       
       Print*, ' '   
       print 106,itot,ibad,nland,rgood,rbad,rland
106    format ('satellite : total obs =',i10,3x,'bad obs =',i8,3x,
     1 'land obs =',i8/'  % good sst=',f10.5,3x,
     2 '% bad sst =',f10.5,3x,'% land sst =',f10.5)

c*        icheck=0
	call supersat(dsat,dim_dsat,151,file_dgrid_out,file_dsobs_out,
     1                imax,ax1,ay1,blat,blon,iyrmid,immid,idmid,isource,
     2                isup)
        
c     caculate dsat sobs coverage 
       cover=100.0*float(isup)/sea_ict
       
       print*,'dsat sobs coverage=',cover
       if(cover.lt.cov_sat2)then 
      
       print 888,ctype(1),cover
888    format ('RED-STOP! SATELLITE-MAIN',3x,a8,
     1  ' sobs coverage too low, cover=',f5.2)
c       print*, 'RED-STOP! SATELLITE-MAIN',ctype(1),
c     1 ' sobs coverage too low, cover=',cover
cliu      call exit (100) 
      endif 
      
      if(cover .ge. cov_sat2 .and. cover.lt.cov_sat)then 
      print 999,ctype(1),cover
c999   format ('YELLOW-WARNING! SATELLITE-MAIN',3x,a8,
c     1  ' sobs coverage too low, cover=',f5.2)      
c*      icheck=1
cliu      call exit (10) 
      endif
       
                    
	call supersat(nsat,dim_nsat,152,file_ngrid_out,file_nsobs_out,
     1                imax,ax1,ay1,blat,blon,iyrmid,immid,idmid,isource,
     2                isup)
     
c     caculate nsat sobs coverage 
       cover=100.0*float(isup)/sea_ict
       
       print*,'nsat sobs coverage=',cover
       if(cover.lt.cov_sat2)then 
       print 888,ctype(2),cover
c        print*, 'RED-STOP!  SATELLITE-MAIN', ctype(2),
c     1 ' sobs coverage too low, cover=',cover
      call exit (100) 
      endif 
      
      if(cover .ge. cov_sat2 .and. cover.lt.cov_sat)then 
      print 999,ctype(2),cover
c      print*, 'YELLOW-WARNING! SATELLITE-MAIN',ctype(2),
c     1 ' sobs coverage too low, cover=',cover
      call exit (10) 
      endif
          
	print*,'iflag=',iflag
	
	call timer (itime2)
        tsec = float(itime2-itime1)*.01
        print *,tsec,' seconds for complete AVHRR QC code'
	
	goto 9999
                                        
1234  print*,'RED-STOP! SATELLITE-MAIN:',
     1       '???????? 6hr file does not exist ?????????' 
      call exit (100) 
      
       
1235  print*,'RED-STOP! SATELLITE-MAIN:', 
     1       'first guess does not exist ?????????'    
      call exit (100) 
 
      
5000  print 5001
5001  format('RED-STOP! SATELLITE-MAIN:
     1        unexpected end of first guess file oisst')
      call exit (100)
      
c9999  if(icheck .gt. 0)then      
c      print 999,ctype(2),cover
999   format ('YELLOW-WARNING! SATELLITE-MAIN',3x,a8,
     1  ' sobs coverage too low, cover=',f5.2)
c      call exit(10)
c      endif 

9999      if(iflag .gt. 0)then
        print*,'YELLOW-WARNING! SATELLITE-MAIN:',
     1         'Too many obs:imax=',imax
        call exit(10)
      endif
      	
c      print*,'GREEN-SUCCESSFUL! satellite_navy MAIN'
      call exit(1) 
      end

		
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc   
c
c   subprogram:  supersat  caculate satellite super obs.              
c                                                                       
c abstract:  In the main, the satellite obs are read and passed the 
c            simple QC(such as on land, lat lon are within the globe, 
c            sst not mssing, ...) are stored in arrays called 
c            dsat(dim_dsat) and nsat(dim_nsat) seperately.
c            The array includes sst, position(latitude and longitude), and time.
c   
c            In this subroutine, first qsort dsat and nsat, get rid of 
c            the duplicated obs. then caculate the super obs-the average 
c            of sst,latitude, longitude and sst standard deviation 
c            in each 1 degree box.                     
c                                                                       
c program history log:                                                  
c   ?????-??-??  richard w. reynolds                                       
c   
c   2005-01-20  Chunying Liu     - Add duplicated check and get rid off the 
c                                  duplicated records
c                                - make the code to a subroutine  
                                    
c  usage:       call supersat(dsat,dim_dsat,151,file_dgrid_out,doisst,dstdev,
c        1                    iyrmid,immid,idmid)
c	        call supersat(nsat,dim_nsat,152,file_ngrid_out,doisst,dstdev,
c       1                     iyrmid,immid,idmid)
c               call supersat(xsat,dim_xsat,159,file_ngrid_out,doisst,dstdev,
c       1                     iyrmid,immid,idmid)
c     
c                                                                       
c   input argument list:
c                                                
c     iyrst,imonst,idast - starting day of data to be extracted.                  
c              - the day is yyyy,mm,dd. 
c     iyrst,imonst,idast - ending day of data to be extracted.                  
c              - the day is yyyy,mm,dd
c     clima1   - the 1 degree resolution mean sst climatology for       
c              - the center of the period of interest.                  
c     clims1   - the 1 degree resolution standard deviation of the      
c              - sst, for center of the period of interest,             
c              - times smult.                                           
c              - (presently smult=3.5 in the main program )             
c              - the grid for both clima1 and clims1 is centered on     
c              - the half degree.  the first index is longitude         
c              - from 0.5e to 359.5e (range 1 to 360).  the second      
c              - index is latitude from -89.5 (89.5s) to 89.5 (89.5n)  
c
c     dsat      -  day time satellite observations
c               -  character*18 array 
c               -  the first two characters are the relative day for the     
c               -  period, the next two characters are the hour.
c               -  character 5:18 are latitude, logitude, and sst.                       
c     dim_dsat  -  total day time satellite observations
c     nsat      -  night time satellite observations
c               -  character*18 array 
c               -  the first two characters are the relative day for the     
c               -  period, the next two characters are the hour.
c               -  character 5:18 are latitude, logitude, and sst.                       
c     dim_nsat  -  total night time satellite observations 
c         
c                                                         
c    output files:                              
c     file_out1     - day time satellite superobs.
c                    /raid2/sstday/YYYY/sobs/navy/dsat/dsat.YYYYMMDD
c
c     file_out1     - night time satellite superobs.
c                    /raid2/sstday/YYYY/sobs/navy/nsat/nsat.YYYYMMDD
c                                                                       
c                                                                       
c   language: fortran 90 
c   machine:  Red hat linux
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc                                                                      

       subroutine supersat(name,dim,iu,file_grid_out,file_sobs_out,
     1           imax,ax1,ay1,blat,blon,iyrmid,immid,idmid,isource,isup)
       parameter (nbig=10000)
       character*80 file_grid_out,file_sobs_out
       character*16 name(imax)
c       real clima1(362,180),clims1(362,180)         
       real alat,alon
       dimension num(1440,720)
       real sst(1440,720)
       dimension blat(720),blon(1440)
       integer ict,dim,dim3
       dimension yt(180),xt(362)
       dimension wsst(nbig),wlat(nbig),wlon(nbig),wnum(nbig)
       character*8 ctype(2)
c       data ctype /'dsat_16 ','nsat_16 '/
       
       external compar
       integer*2 compar 
       
       if(isource.eq.7)then
       ctype(1)='dsat18  '
       ctype(2)='nsat18  '
       endif
       
       if(isource.eq.6)then
       ctype(1)='dsat17  '
       ctype(2)='nsat17  '
       endif
       
       if(isource.eq.2)then
       ctype(1)='dsat16  '
       ctype(2)='nsat16  '
       endif
       
       if(isource.eq.12)then
       ctype(1)='dmetop  '
       ctype(2)='nmetop  '
       endif
       
c       print*,ctype(1)
              
c       ctype(1)='dsat_16 '
c       ctype(2)='nsat_16 '
c       
c       ijd_change = iw3jdn(2003, 5, 1)       
c       ijdmid = iw3jdn(iyrmid, immid, idmid)
c       if(ijdmid .ge. ijd_change)then       
c       ctype(1)='dsat_17 '
c       ctype(2)='nsat_17 '
c       endif
       
       undef = -9999.
            
       do i=1,1440
       do j=1,720
       num(i,j)=0
       sst(i,j)=0
       enddo
       enddo            
       
       ix=iu-100
       iw=iu-90       
       iv=iu-80
       ic=iu-150
       
       if(iu.eq.159)ic=3
       
       write (iv) iyrmid,immid,idmid,ctype(ic)
       
       print*,' '
       print*,'--------------------------------------------'
       print*, 'caculate sobs for  ', ctype(ic)
      
       call qsort(name,dim,16,compar)
          
c************************************************************************ 
c   duplicate check               
       
       dim3=0
       name(dim+1)=name(1)
       
555    do i=2,dim+1
       j=i-1
        if(name(i).ne.name(j))then
         dim3=dim3+1
       
         write(ix,666)name(i)
666      format(a16)  

         read(name(i),888)ilat,ilon,isst
888      format(2x,i5,i6,i3)       
         alat=0.01*ilat
         alon=0.01*ilon
         asst=0.1*isst
       
c      caculate the row and col number of this good obs   
                                                          
       	 ii = 1 + nint(4.*(alon-ax1))
	 if (ii.eq.0) ii = 1
         if (ii.eq.1441) ii = 1440
		
         jj = 1 + nint(4.*(alat-ay1))
         if (jj.eq.0) jj = 1
         if (jj.gt.720) jj = 720
	
c     add this obs to the right grid box
       
         num(ii,jj)=num(ii,jj)+ 1
         sst(ii,jj)=sst(ii,jj)+ asst      
      
        endif
       enddo
                    
       print*, 'satellite obs before and after duplicated check:'
       print 777,iyrmid,immid,idmid,dim,dim3
      
777    format('sat_obs:',i5,2i3,2i8) 

c************************************************************************          

c      caculate sst in one grid box, ie. super obs.  
c      And write sobs to a one big array    
       
       i_sumnum=0
       
       do i=1,1440
       do j=1,720
       if(num(i,j).gt.0)then
	  i_sumnum = i_sumnum + num(i,j)
	  sst(i,j)=sst(i,j)/float(num(i,j))
          else
	  sst(i,j)=undef
       endif
       enddo
       enddo 
       
c       print*,'i_sumnum=',i_sumnum
              
	ict=0
        isup=0
	iwrt = 0               
	do i=1,1440
        do j=1,720
	if(num(i,j).gt.0)then
	ict=ict+1	
	wnum(ict)=float(num(i,j))
        wsst(ict)=sst(i,j)
	wlat(ict)=blat(j)
	wlon(ict)=blon(i)
        endif
	
	if(ict .eq. nbig)then
c	  icts = ict
	  iwrt = iwrt + 1
	  write(iv)  ict
	  write(iv) (wnum(ii),ii=1,ict)                                    
          write(iv) (wsst(ii),ii=1,ict)                                    
          write(iv) (wlat(ii),ii=1,ict)                                    
          write(iv) (wlon(ii),ii=1,ict) 
	
c	  call maxmin (wnum,ict,1,undef,'    wnum')
c	  call maxmin (wsst,ict,1,undef,'    wsst')
c	  call maxmin (wlat,ict,1,undef,'    wlat')
c	  call maxmin (wlon,ict,1,undef,'    wlon')                                   
                                                                                             
          isup = isup + ict 
	  ict=0
	endif  	                                                
                                                                            
       enddo
       enddo
       
        if(ict.gt.0)then
        isup=isup+ict
	iwrt = iwrt + 1
	icts = ict
	write(iv) ict
        write(iv) (wnum(ii),ii=1,ict)                                    
        write(iv) (wsst(ii),ii=1,ict)                                    
        write(iv) (wlat(ii),ii=1,ict)                                    
        write(iv) (wlon(ii),ii=1,ict)
	endif 
	
	call maxmin (wnum,ict,1,undef,'    wnum')
	call maxmin (wsst,ict,1,undef,'    wsst')
	call maxmin (wlat,ict,1,undef,'    wlat')
	call maxmin (wlon,ict,1,undef,'    wlon')
	
c     Write out the grid obs SST
      
      write (iw) iyrmid,immid,idmid,sst
      
      Print*, ' '
      call maxmin (sst,1440,720,undef,ctype(ic))
       
      Print*, ' '
      print 111,ctype(ic),isup,icts,iwrt
111   format (a8,3x,'number sup obs =',i10,3x,'last ict =',i8,
     1  3x,'num writes =',i3)
     
c     caculate buoy or ship obs coverage 
c      cover=100.0*float(isup)/698057.0
c      if(cover.lt.cov_sat)then 
c      print*, 'YELLOW - WARNING - SATELLITE-SUBROUTINE-supersat',
c     1 ctype(iu),' obs coverage too low, cover=',cover 
c      Print*, ctype(iu), ' total obs =', i_sumnum  
c      endif

      return
      end   
       
c********************************************************************************      
     
       subroutine dayclm (stdev,imo,ida,dclim,ierr)
c    stdev   - field of the 12 months of climatology                  
c              - dimension (12,360,180)                                  
c              - the first index is the month,                          
c              - from january (= 1) to december (=12)                   
c              - the second index is longitude: (0.5E to 359.5e) 
c                          ...corrected lon range in comment 10 Feb 2000
c              - the third index is latitude: (89.5s to 89.5n)              
c     imo      - month of desired interpolated climatology              
c     ida      - day of desired interpolated climatology                
c                                                                       
c   output argument list:                                               
c     dclim    - field of the temporally interpolated                   
c              - climatology for imo and ida                            
c              - dimension (362,180)                                     
c              - the first index is longitude: (0.5w to 360.5e) 
c              - the second index is latitude: (89.5s to 89.5n)         
c              - note: if extra longitude values are requested,
c              -       dclim(1,j) = dclim(361,j)   
c              -       dclim(362,j) = dclim(2,j) 
c     ierr     -  equal to 0 if interpolated field found                
c              -  equal to 1 if no interpolated field because of        
c              -  bad imo or ida or                  
c                                                                       
c   output files:                                                       
c     fort.06  - printout                                               
c                                                                       
c remarks:  
c                                                                       
c attributes:                                                           
c   language: fortran 77                                                
c   machine:  cray                                                       
c                                                                       
c$$$                                                                    
      integer*4 ndays(12)
      dimension stdev(12,360,180)
      dimension dclim(362,180)
      data ndays/31,28,31,30,31,30,31,31,30,31,30,31/
c  change february 29 to february 28: effect of leap year ignored       
      ierr = 0
c
      if (imo.eq.2.and.ida.eq.29) ida = 28
c                                                                       
c      print 10, imo,ida
c   10 format('interpolated climate for month = ',i3,3x,'day =',i3)
c  check for bad date                                                   
      if (imo.lt.1.or.imo.gt.12.or.ida.lt.1.or.ida.gt.ndays(imo)) then
      print 222
  222 format (' warning interpolation error in dclim')
      ierr = 1
      return
      endif
      halfm1 = real(ndays(imo))/2.
      if (ida.le.int(halfm1)) then
        if (imo.eq.1) then
          jmo = 12
        else
          jmo = imo-1
        endif
        d = halfm1 - real(ida) + .5
      else
        if (imo.eq.12) then
          jmo = 1
        else
          jmo = imo+1
        endif
        d = real(ida) - halfm1 - .5
      endif
      halfm2 = real(ndays(jmo))/2.
      span = halfm1+halfm2
      do i=1,360
        ip = i + 1
        do j=1,180
	  t1 = stdev(imo,i,j)
          t2 = stdev(jmo,i,j)
          dclim(ip,j) = ((t2-t1)/span)*d + t1
        enddo
      enddo
      do j=1,180
        dclim(1,j)   = dclim(361,j)
        dclim(362,j) = dclim(2,j)
      enddo
      return
      end
      
      
c      subroutine intrp (cn,imc,ic,jc,fn,imf,if,jf,cx,cy,fx,fy,ierr)
c$$$  subprogram documentation block                                    
c                .      .    .                                       .  
c subprogram:    intrp      finds interpolated field fn                 
c   prgmmr: r. w. reynolds   org: w/np24     date: 1990-12-31             
c                                                                       
c abstract: finds a linearly interpolated field fn defined by           
c     array locations fx and fy within input field cn that is           
c     defined by array locations cx and cy. fx and cx are locations     
c     of first index of fn and cn, respectively, fy and cy are          
c     locations of the second index.                                    
c                                                                       
c program history log:                                                  
c   1990-12-31  richard w. reynolds                                       
c   2000-02-01  Diane C. Stokes    - move to IBM SP
c                                                                       
c usage:    call intrp (cn,imc,ic,jc,fn,imf,if,jf,cx,cy,fx,fy,ierr)     
c                                                                       
c   input argument list:                                                
c     cn       - gridded field                                          
c              - at locations defined by cx and cy                      
c     imc      - actual first dimension of cn in calling routine        
c     ic       - first dimension of cn                                  
c     jc       - second dimension of cn                                 
c     cx       - distribution of grid points in cn (first index)        
c     cy       - distribution of grid points in cn (second index)       
c     imf      - actual first dimension of fn in calling routine        
c     if       - first dimension of fn                                  
c     jf       - second dimension of fn                                 
c     fx       - distribution of grid points in fn (first index)        
c     fy       - distribution of grid points in fn (second index)       
c                                                                       
c   output argument list:      (including work arrays)                  
c     fn       - linear interpolated field                              
c              - at locations defined by fx and fy                      
c     ierr     - ierr = 0: interpolated field ok                        
c              - ierr = 1, fn = 0:    no interpolation possible         
c              - because cx, cy, fx, or fy do not monitonically         
c              - increases or fx and fy arrays not within cx and cy     
c              - arrays respectively.                                   
c              - if ierr=1, error messages are printed                  
c                                                                       
c   output files:                                                       
c     fort.06  - printout                                               
c                                                                       
c remarks:  subrotuine orignally written by ron pacanowski, gfdl/noaa   
c                                                                       
c attributes:                                                           
c   language: fortran 90                                                
c   machine:  IBM SP
c                                                                       
c$$$                                                                    
           
      subroutine intrp1 (cn,imc,ic,jc,cx,cy,fx,fy,fn,ierr)
      dimension cn(imc,jc),cx(ic),cy(jc)
      if (fx.lt.cx(1).or.fx.gt.cx(ic)) go to 10
      if (fy.lt.cy(1).or.fy.gt.cy(jc)) go to 10
      do 110 l=1,jc
      if (cy(l).lt.fy) go to 110
      jn = l
      js = l-1
      if (js.eq.0) jn = 2
      if (js.eq.0) js = 1
      go to 111
  110 continue
      jn = jc
      js = jc - 1
  111 continue
      do 120 l=1,ic
      if (cx(l).lt.fx) go to 120
      ie = l
      iw = l-1
      if (iw.eq.0) ie = 2
      if (iw.eq.0) iw = 1
      go to 121
  120 continue
      ie = ic
      iw = ic - 1
  121 continue
      a = (fx - cx(iw))
      b = (cx(ie) - fx)
      c = fy - cy(js)
      d = cy(jn) - fy
      ac = a*c 
      bc = b*c 
      ad = a*d 
      bd = b*d
      top = ac*cn(ie,jn) + bc*cn(iw,jn) + ad*cn(ie,js) + bd*cn(iw,js)
      bot = ac + bc + ad + bd
      ierr = 0
      fn = top/bot
      return
c
c     no interpolated value
c
   10 print 15
   15 format (' problem in intrp1: fx or fy out of range;',
     1 '   no interpolated value')
      print 20,cx(1),cx(ic),fx
   20 format (' cx(1) =',f10.3,3x,'cx(ic) =',f10.3,3x,'fx =',f10.3)
      print 25,cy(1),cy(jc),fy
   25 format (' cy(1) =',f10.3,3x,'cy(jc) =',f10.3,3x,'fy =',f10.3)
      ierr = 1
      return
      end
      
      
      subroutine maxmin (fld,im,jm,undef,name)
c
c   compute maximum, minium and average of fld and print
c
      dimension fld(im,jm)
      character*8 name
      real*8 ave,r
      fldmin = 1.e30
      fldmax = -fldmin
      inum = 0
      ave = 0.
      do 90 i=1,im
      do 90 j=1,jm
      if (fld(i,j).ne.undef) then
        inum = inum + 1
        ave = ave + fld(i,j)
        if (fldmin.gt.fld(i,j))  fldmin = fld(i,j)
        if (fldmax.lt.fld(i,j))  fldmax = fld(i,j) 
      endif
   90 continue
      if (inum.gt.0) then
        r = 1./float(inum)
        ave = ave*r
      else
        fldmin = 0.
        fldmax = 0.
      endif
      print 88,ave,fldmin,fldmax,inum,name
   88 format (' ave =',f10.3,2x,'min =',f10.3,2x,
     1 'max =',f10.3,2x,'inum =',i8,2x,a8)
      return 
      end
      
      integer*2 function compar(arg1,arg2)
      character*16 arg1,arg2
      if(arg1.lt.arg2) then
        compar=-1
      else if(arg1.eq.arg2) then
        compar=0
      else
        compar=1
      endif
      return
      end
      
      SUBROUTINE GETFG (IUN,IMX,IMY,IERR,iday,NDAYS,gsst,undef)
      DIMENSION GSST(IMX,IMY)     
      IERR = 0
C - READING IN THE FIRST-GUESS
      READ (IUN,END=6000) jyr,jmo,jda,gsst
      PRINT 10,jyr,jmo,jda
   10 FORMAT (' GUESS DATE:  YEAR =',I5,3X,'MONTH =',I3,
     1 3X,'DAY =',I3)
      jday =  iw3jdn (jyr,jmo,jda)
      if (iday-jday.ne.ndays) then
        print *,'FIRST GUESS DATE ERROR: Program ends'
	go to 6000
      endif
      RETURN
 6000 PRINT 7000
 7000 FORMAT(' ERROR! - NO FIRST-GUESS: IERR=1 IN GETFG')
      IERR = 1
      RETURN
      END
 
      
      include '/home/cliu/lib/w3lib/iw3jdn.f'
      include '/home/cliu/lib/w3lib/w3fs26.f'
      
 
